function      dataprep_help(index)
%% help file for data preparation panel

%%  Kriging Software Package  version 2.0,   October 29, 1999
%%  Copyright (c) 1999, property of Dezhang Chu and Woods Hole Oceanographic
%%  Institution.  All Rights Reserved.

global hdl para

varname=[];
content=[];

switch index
  case 1				
	  varname='Data File Format';
     content={''};
  case 2
	  varname='Data File Format: X-Axis, Y-Axis, and Z-Axis';
     content={'The data file should be a plain text file (ASCII format). There should be three' ...
              'columns for a 2D case and four columns a 3D case. For a 2D data file, use X-Axis'...
              'and Y-Axis settings only. All settings in the X-Axis column are associated with'...
              'x-axis settings. '...
              '  '...
              'Similarly, all settings for Y-Axis and Z-Axis columns are associated '...
              'with y-axis and z-axis settings, respectively.'};
  case 3
	  varname='Data File Format: Column';
	  content={'There are three column ASCII file for 2D data and four columns for 3D data.'...
              'This option allows users to determine which variable will be displayed as the ' ...
              'variable for x-axis, y-axis, or z-axis. Default setting is to display the ' ...
              'variable of the second column in the data file as x-axis (longitude), the variable ' ...
              'of the first column as y-axis (latitude), and the variable of the third column '...
              'as z-axis (depth).'...
              '   '...
              'If the original data file has more than three columns for a 2D case or four'...
              'columns for a 3D case and the user does not want to create a separate data file,'...
              'the user can write a simple m-file and use ''External Program'' option (see'...
              '''External Program'' help) to read the original data file directly.'};
  case 4
     varname='Data File Format: Variable';
     content={'Names of the selected variables.'};
  case 5
     varname='Data File Format: Axis Label';
     content={'Displayed axis labels for the corresponding variables.' ...
             'If the user selects the ''Other'' in the ''Variable'' option,'...
             'the user can enter appropriate label(s) in the ''Label'' field(s).'};
  case 6
     varname='Data File Format: Variable Unit';
     content={'Display units of the selected variables.'...
             'If the user wants to use a different unit than the default, the user'...
             'can enter the appropriate unit here. This ''Unit'' is only for display'...
             'and will not affect the kriging results.'};
  case 7
     varname='Data File Format: Direction';
     content={'Display directions of x, y, and z axes. Select the corresponding reverse if'...
             'one wants to reverse the axis display.'};
  case 8 
     varname='Save Data Format';
     content={'Save data format information to a file for future reference, '...
             'especially for batch processing.'};
  case 9 
     varname='Data Reduction: Reduction Factor';
     content={'Ratio of the number of the original data points to the number of ' ...
             'the reduced data points. The reduced data will be used for ' ...
             'variogram and kriging computations.'...
             '       '};
  case 10
	  varname='Data Reduction: Filter';
     content={'Filter Type: ' ...
        '          Simple: Simple data reduction (skip points).' ...
        '           ' ...
     	'          Mean: Average over a specified support length (see the explanation for Support).' ...
        '         ' ...
        '          Median: Using median value over the specified support.' ...
        '       ' ...
        '     Note that if filter support is 1, filtering has no effect on data reduction. Data reduction' ...
        '     is just a ''Simple'' data reduction, i.e., Filter_type 1.'};
  case 11
     varname='Data Reduction: Support';
     content={
      'Filter length. For example, a mean filter with support 5 will generate a smoothed data series'...
      'for which each data point is the mean value of the adjacient 5 data points. If the Data Reduction',...
      'factor is greater than 1, the filter process will be done after data reduction.'...
      '   '...
       'Note that for support of 1, filtering has no effect.'};
  case 12
     varname='External (user defined) Program:';
     content={
		   'This option allows user to use his(her) program to access their '...
            'data without creating a separate data file. The syntax to call '...
            'the external program is:' ...
            '     '...
			'    [x,y,var]=function_name(filename);' ...
            '   ' ...
            'for a 2D case, and'...
            '   ' ...
			'    [x,y,z,var]=function_name(filename);'...  
            '    '...
            'for a 3D case. The output array has three columns for a 2D case and four'...
            'columns for a 3D case, where x, y, and z coordinate column arrays, '...
            'respectively, and var is the data value (a column array). ''function_name'' is'...
            'the name of your program specified, either by typing in the filename field or ' ...
            'using the file browser. After selecting the ''External Program'', the data file can be '...
            'obtained by using the data file browser after clicking the ''Load'' command button. '...
            '         '...
            'Note that this option should be selected before you load the file!'};
  case 13
     varname='Data Transformation';
     content={'To allow user(s) to transform a raw data set with ',
        'a larger dynamic range to a new data set with a smaller',
        'dynamic range using a formula chosen from the listed',
        'available transformations.',
        '      ',
        'Example 1:  log10(z) transforms z=[1 10 1000] to [0 1 3].',
        '   ',
        'Example 2:  log10(z+1) transforms z=[0 10 1000] to [0 1.0414 3.0004].',
        '   ',
        'Note that if the raw data include zeros, one needs to select',
        'either log10(z+1) or log(z+1) since both log10(0) and log(0)',
        'will return -inf.'};    
  case 14
     varname='Axes Conversion';
     content={'Y to X - values of y-axis are multiplied by this factor.',
              'Z to X - values of y-axis are multiplied by this factor.'};
  case 15
     varname='Data Display Type';
     content={'2D/3D Color-coded View  --  Color-coded sample amplitude in a 2D or 3D domain.',
              '        Sample Sequence  --  Sample Values as a function of sample number.'};
  case 16
     varname='File';
     content={'Filename of the loaded input file. It enables user(s)to '...
             'keep track the processed file.'};
  case 17
     varname='Push Buttons';
     content={'Load - load data file. The data can also be loaded using the File|Load from',
              '       the Tool-Bar.',
     '   ',
     'Apply - apply data reduction, data transformation operations without reloading data.',
     '   ',
     'Navigator - return to the base window (Navigator).',
     '   ',
     'Quit - close this window.'};
  case 18                              % not used
     varname='Anisotropy:  angle and aspect ratio';
     content={'These two parameters will allow user(s) to transform',
        'the raw data set with an anisotropic feature along one direction',
        'to an isotropic data set. Semi-variogram and kriging are performed'
        'using transformed data, but the final kriging results are still'
        'displayed in the original coordinates, i.e., user will not see the'
        'intermediate results in their isotrophic form.',
        '   '
        'Angle: Rotation angle needed to transform anisotropic values', 
        '        along a particular direction (angle) to along horizontal',
        '        and vertical axes. Angle is in degrees and measured counterclockwise',
        '        from the horizontal axis.',
        '       ',
        'Aspect Ratio: Ratio of the vertical range to horizontal'
        '        range in the rotated coordinates'};
  otherwise
     varname='Not Available !';
     content='Coming Soon ...';
end

if ~isempty(varname) & ~isempty(content)
  if para.Matlab_Version == 5
     help_message(content,varname,[0 0 0]);
  elseif para.Matlab_Version >= 6
     p=general_message('no_action',varname,content);
  end
end
