%single_plot(single_plot_index)
%% single_plot()
%%  displays individual plot in a separate window
%%
%%  EasyKrig Software Package  version 2.0,   October 1, 1999
%%  Copyright (c) 1999, property of Dezhang Chu and Woods Hole Oceanographic
%%  Institution.  All Rights Reserved.

if isempty(findobj('Tag','Single_plot_window'))
	hdl.dispkrig.single_plot= figure('Units','normalized', ...
		'Color',[0.8 0.8 0.8], ...
		'Name','EasyKrig 2.0 -- INDIVIDUAL PLOT', ...
		'RendererMode','manual','Tag','Single_plot_window');
else
   figure(hdl.dispkrig.single_plot);
end

switch single_plot_index
  case 1
		pcolor(Xg,Yg,Cg);shading interp
		axis([ xgmin xgmax ygmin ygmax])
		colorbar;
	   hold on
		clr=min(max(floor(clr_max*(var-min(var))/(max(var)-min(var))),0)+1,clr_max);
		cmap=colormap;
		n=length(xs);
		inc=max(1,round(n/1600));
		track_color='ymcrgbwk';
		clr_indx=TrackLineColor+6;
		switch TrackLineType
			case 1			% color-coded tracklines
 				for i=1:inc:n
   				plot(xs(i),ys(i),'.','color',cmap(clr(i),:),'markersize',markersize);
 				end
   		case 2		% black/white tracklines
  				if n >= 100
    				hxy=plot(xs,ys,['.' track_color(clr_indx)],'linewidth',2.5);
  				else
    				hxy=plot(xs,ys,['.' track_color(clr_indx)],'markersize',markersize);
  				end
			case 3		% attribute values
  				hxy=plot(xs,ys,['.' track_color(clr_indx)],'markersize',markersize);
  				htxt=text(xs,ys,num2str(var));
  				set(htxt,'fontsize',para.dispkrig.trackline.size_indx,'color',track_color(para.dispkrig.trackline.color_indx));
			case 4		% difference between observed and kriged attribute values 
  				hxy=plot(xs,ys,['.' track_color(clr_indx)],'markersize',markersize);
  				htxt=text(xs,ys,num2str(var-Is));
  				set(htxt,'fontsize',para.dispkrig.trackline.size_indx,'color',track_color(para.dispkrig.trackline.color_indx));
		end
		if ~isempty(vKrig)
  			if isnan(vKrig) 
    			[c,H]=contour(Xg,Yg,Cg,'k');
  			else
    			[c,H]=contour(Xg,Yg,Cg,vKrig,'k');
  			end
  			hh=clabel(c,H);
		end
	   hold off
  		if para.dataprep.file_col1_index <= 2 | para.dataprep.file_col2_index <= 2	% either x or y is Lat or Long
     		ntick=4;
     		[xinc,xdits,yinc,ydits]=get_ninc(gca,ntick);
	  		if para.dataprep.file_col1_index <= 2
       		mapax(xinc,xdits,yinc,ydits,gca,1);		% x-axis label
	  		end
	  		if para.dataprep.file_col2_index <= 2
       		mapax(xinc,xdits,yinc,ydits,gca,2);		% y-axis label
	  		end
     		tick_len=size(get(gca,'yticklabel'),2);
     		switch tick_len
       		case 9
					set(gca,'fontsize',9)
       		case 10
					set(gca,'fontsize',8)
     		end
  		end
  		if get(hdl.dispkrig.xdir,'value');
	  		set(gca,'xdir','reverse');
  		else
     		set(gca,'xdir','normal');
  		end
  		if get(hdl.dispkrig.ydir,'value');
	  		set(gca,'ydir','reverse');
  		else
     		set(gca,'ydir','normal');
  		end
  		title('KRIGING MAP','fontsize',14,'fontweight','bold')
 		xlabel(para.dataprep.xlabel,'fontsize',14,'fontweight','bold')
 		ylabel(para.dataprep.ylabel,'fontsize',14,'fontweight','bold')
  case 2
		hxy=pcolor(Xg,Yg,Eg);shading interp;
		hold on
		if ~isempty(vErr)
  			if isnan(vErr)
    			[c,H]=contour(Xg,Yg,Eg,'k');
  			else
    			[c,H]=contour(Xg,Yg,Eg,vErr,'k');
  			end
  			hh=clabel(c,H);
		end
		if TrackLineType < 3
  			if n >= 1000
    			hxy=plot(xs,ys,'w','linewidth',2.5);
  			else
   			hxy=plot(xs,ys,'.w','markersize',markersize);
  			end
		end
		colorbar;
		axis([ xgmin xgmax ygmin ygmax])
		fcmap=colormap;
		hold off
  		if para.dataprep.file_col1_index <= 2 | para.dataprep.file_col2_index <= 2	% either x or y is Lat or Long
     		ntick=4;
     		[xinc,xdits,yinc,ydits]=get_ninc(gca,ntick);
	  		if para.dataprep.file_col1_index <= 2
       		mapax(xinc,xdits,yinc,ydits,gca,1);		% x-axis label
	  		end
	  		if para.dataprep.file_col2_index <= 2
       		mapax(xinc,xdits,yinc,ydits,gca,2);		% y-axis label
	  		end
     		tick_len=size(get(gca,'yticklabel'),2);
     		switch tick_len
       		case 9
					set(gca,'fontsize',9);
       		case 10
					set(gca,'fontsize',8);
     		end
  		end
	   if get(hdl.dispkrig.xdir,'value');
	  		set(gca,'xdir','reverse');
  		else
     		set(gca,'xdir','normal');
  		end
  		if get(hdl.dispkrig.ydir,'value');
	  		set(gca,'ydir','reverse');
  		else
     		set(gca,'ydir','normal');
  		end
  		title('NORMALIZED KRIGING VARIANCE','fontsize',14,'fontweight','bold')
 		xlabel(para.dataprep.xlabel,'fontsize',14,'fontweight','bold')
 		ylabel(para.dataprep.ylabel,'fontsize',14,'fontweight','bold')
  case 3
 	switch	para.dispkrig.validation_model 
		case 1					% double kriging
			sta=1:length(var);
			plot(sta,var,'-o',sta,Is,'+-r');
			hh1=legend('Observation','Prediction');
			set(hh1,'fontsize',10)
			hx=xlabel('SAMPLE NUMBER');
			hy=ylabel('OBSERVATION AND PREDICTION');
			ht=title(['<z - z*> = ' sprintf('%g',mean_nan(var-Is)) '        \sigma = ' sprintf('%g',std_nan(var-Is))]);
			set([hx hy ht],'fontweight','bold','fontsize',14)
		case 2		% JackKnife
			Ijk=data.out.krig.Ijk;
			sta=1:length(var);
			plot(sta,var,'-o',sta,Ijk,'+-r');
			hh1=legend('Observation','Prediction');
			set(hh1,'fontsize',10)
			hx=xlabel('SAMPLE NUMBER');
			hy=ylabel('OBSERVATION AND PREDICTION');
			ht=title(['<z - z*> = ' sprintf('%g',mean_nan(var-Ijk)) '        \sigma = ' sprintf('%g',std_nan(var-Ijk))]);
			set([hx hy ht],'fontweight','bold','fontsize',14)			
		case 3 		% Q-1
			nq=2;
			n=length(xs)-para.krig.model;
	   	[x,fq,Qrej,fr]=pdf_func(para.dispkrig.validation_model,n);		  
			plot(x,fq,'m','linewidth',2.0)
			hold on
			plot(-Qrej*ones(1,2),[0 fr],'k',Qrej*ones(1,2),[0 fr],'k','linewidth',2.0);
			ht1=text(-Qrej+0.1,0.5*fr,'Accept Region');
			if data.out.krig.q1 <= max(x) & data.out.krig.q1 >= min(x)
		   	plot(data.out.krig.q1*ones(1,nq),linspace(0,max(fq),nq),'-r','linewidth',1.5);
				hdt=text(data.out.krig.q1+0.02,0.8*max(fq),'Computed Q_1');
				set(hdt,'fontsize',8,'fontweight','bold');
			end
			set(ht1,'fontsize',10,'fontweight','bold');
			ht=title(sprintf('Q1 = %g',data.out.krig.q1),'fontweight','bold');
			hold off
			hx=xlabel('Q_1');
			hy=ylabel('PDF(Q_1)');
			set([hx hy ht],'fontweight','bold','fontsize',14)
		case 4 		% Q-2
			nq=2;
			n=length(xs)-para.krig.model;
	   	[x,fq,Qrej,fr]=pdf_func(para.dispkrig.validation_model,n);		  
			plot(x,fq,'m','linewidth',2.0)
			hold on
			plot(Qrej(1)*ones(1,2),[0 fr(1)],'k',Qrej(2)*ones(1,2),[0 fr(2)],'k','linewidth',2.0);
			ht1=text(Qrej(1)+0.1,0.5*fr(1),'Accept Region');
			if data.out.krig.q2 <= max(x) & data.out.krig.q2 >= min(x)
		   	plot(data.out.krig.q2*ones(1,nq),linspace(0,max(fq),nq),'-r','linewidth',1.5);
				hdt=text(data.out.krig.q2+0.02,0.8*max(fq),'Computed Q_2');
				set(hdt,'fontsize',8,'fontweight','bold');
			end
			set(ht1,'fontsize',10,'fontweight','bold');
			ht=title(sprintf('Q2 = %g',data.out.krig.q2),'fontweight','bold');
			hold off
			hx=xlabel('Q_2');
			hy=ylabel('PDF(Q_2)');
			set([hx hy ht],'fontweight','bold','fontsize',14)
	end
end
		  index1=para.dispkrig.colormap_indx;
	     clrmap_str=get(eval(sprintf('hdl.dispkrig.colormap.c%g',index1)),'label');
		  set(eval(sprintf('hdl.dispkrig.colormap.c%g',para.dispkrig.colormap_indx)),'checked','off');
		  set(eval(sprintf('hdl.dispkrig.colormap.c%g',index1)),'checked','on');
		  eval(['colormap(' clrmap_str ');']);
