function fig = visualizationfig()
% function fig = visualizationfig()
% opens the visualization window
%
%%  EasyKrig Software Package  version 2.0,   October 1, 1999
%%  Copyright (c) 1999, property of Dezhang Chu and Woods Hole Oceanographic
%%  Institution.  All Rights Reserved.

global hdl para

grey=[0.75 0.75 0.75];
dark_grey=[0.65 0.65 0.65];

txt_w8=hdl.object.txt_w8;
Ly=txt_w8;
pmenu_w=hdl.object.popmenu;
radio_w=hdl.object.radio_w;
etxt_w=0.034;

if ~isempty(findobj('type','figure','Tag','DisplayKrig'))
  figure(hdl.dispkrig.h0);
  set(hdl.dispkrig.fileID,'string',para.dataprep.fileID);
  return
end

hdl.dispkrig.h0= figure('Units','normalized', ...
	'Color',[0.8 0.8 0.8], ...
	'Name','EasyKrig 2.0 -- Display Kriging Results', ...
	'Position',hdl.window_position, ...
	'Renderer','zbuffer', ...
	'RendererMode','manual', ...
	'Tag','DisplayKrig');
	set(gcf,'menubar','none');

% File ID
hdl.dispkrig.fileID = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'FontWeight','bold', ...
	'ForegroundColor',[0 0 0.501960784313725], ...
	'Position',[0.27 0.95 0.48 txt_w8], ...
	'String','', ...
	'Style','text', ...
	'Tag','KrigFileID');

%% figure
hdl.dispkrig.axes1 = axes('Parent',hdl.dispkrig.h0, ...
	'Color',[1 1 1], ...
	'Position',[0.1 0.55 0.40 0.35], ...
	'Tag','dispkrigAxes1');

hdl.dispkrig.axes2 = axes('Parent',hdl.dispkrig.h0, ...
	'Position',[0.55 0.55 0.40 0.35], ...
	'Tag','dispkrigAxes2', ...
	'Color',[1 1 1]);

hdl.dispkrig.axes3 = axes('Parent',hdl.dispkrig.h0, ...
	'Position',[0.1 0.1 0.40 0.35], ...
	'Tag','dispkrigAxes3', ...
	'Color',[1 1 1]);

x0=0.6;y0=0.45;
%% axes direction
hdl.dispkrig.xdir = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Callback','radio_action(4,1)', ...
	'FontWeight','bold', ...
	'Position',[x0 y0  0.15 txt_w8 ], ...
	'String','x-axis Reverse', ...
	'Style','radio');
hdl.dispkrig.ydir = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Callback','radio_action(4,2)', ...
	'FontWeight','bold', ...
	'Position',[x0+0.15 y0  0.15   txt_w8], ...
   'String','y-axis Reverse', ...
	'Style','radio');

%% display transformed/untransformed data option
y2=0.41;
hdl.dispkrig.transform = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Callback','radio_action(4,3)', ...
	'FontWeight','bold', ...
	'Position',[x0 y2 0.24 radio_w], ...
	'String','Transformed Data', ...
	'Style','radio', ...
	'Tag','DataTransform');
h1 = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'Callback','dispkrig_help(1);', ...
	'FontWeight','bold', ...
	'Position',[x0+0.24 y2 Ly Ly], ...
	'String','?', ...
	'Tag','DataTransfromHelp');

%% Display Threshold
y1=0.37;
dy=0.07;
h1 = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'HorizontalAlignment','left', ...
	'FontWeight','bold', ...
	'Position',[x0 y1 0.18 txt_w8], ...
	'String','Display Threshhold', ...
	'Style','text');
if ~isfield(para.krig,'elim')
   elim=1.5;
   para.krig.elim=elim;
else
   elim=para.krig.elim;
end
hdl.dispkrig.err_lvl = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'HorizontalAlignment','left', ...
	'Position',[x0+0.19 y1 0.095 etxt_w], ...
	'String',elim, ...
	'Style','edit', ...
	'Tag','dispthreshold');
h1 = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'Callback','dispkrig_help(2);', ...
	'FontWeight','bold', ...
	'Position',[x0+0.29 y1 Ly Ly], ...
	'String','?');

%% single plot option
y1=0.33;
dy=0.07;
plot_str={'1.  Kriging Map','2.  Variance Map','3.  Cross Validation'};
h1 = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'HorizontalAlignment','left', ...
	'FontWeight','bold', ...
	'Position',[x0 y1 0.12 txt_w8], ...
	'String','Single Plot', ...
	'Style','text');
hdl.dispkrig.single_plot_opt = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','popupmenu_action(4,2)', ...
	'FontWeight','bold', ...
	'Position',[x0+0.12 y1 0.20 Ly], ...
	'String',plot_str, ...
	'Style','popupmenu', ...
	'Tag','SinglePlot');
h1 = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'Callback','dispkrig_help(3);', ...
	'FontWeight','bold', ...
	'Position',[x0+0.32 y1 Ly Ly], ...
	'String','?');

y0=0.25;
model_str={'1.  double kriging','2.  leaving-one-out','3.  Q-1','4.  Q-2'};
h1 = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'HorizontalAlignment','center', ...
	'FontWeight','bold', ...
	'Position',[x0 y0 0.2 txt_w8], ...
	'String',' Corss-Validation', ...
	'Style','text');
h1 = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'Callback','dispkrig_help(4)', ...
	'FontWeight','bold', ...
	'Position',[x0+0.20 y0 Ly Ly], ...
	'String','?', ...
	'Tag','CrossValidHelp');
hdl.dispkrig.validationmodel = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','popupmenu_action(4,1)', ...
	'FontWeight','bold', ...
	'Position',[x0 y0-pmenu_w 0.2 pmenu_w], ...
	'String',model_str, ...
	'Style','popupmenu', ...
	'Tag','ValidationModel');
h1 = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'Callback','dispkrig_help(5)', ...
	'FontWeight','bold', ...
	'Position',[x0+0.20 y0-pmenu_w+0.005 Ly Ly], ...
	'String','?', ...
	'Tag','CrossValidHelp');


%% Pushbutton for Action
pbtn_w=hdl.object.pushbtn_w;
pbtn_l=hdl.object.pushbtn_l;
h1 = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'Callback','dispkrig(1)', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'Position',[0.6 0.05+pbtn_w+0.01  pbtn_l pbtn_w], ...
	'String','Show Plot');
h1 = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'Callback','file_browser(4,1)', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'Position',[0.60 0.05 pbtn_l pbtn_w], ...
	'String','Load', ...
	'Tag','Loading');
h1 = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'Callback','figure(hdl.navigator.h0)', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'Position',[0.80 0.05+pbtn_w+0.01  pbtn_l pbtn_w], ...
	'String','Navigator');
h1 = uicontrol('Parent',hdl.dispkrig.h0, ...
	'Units','normalized', ...
	'Callback','close_window(4);', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[0.80 0.05  pbtn_l pbtn_w], ...
	'String','Quit');

hdl.dispkrig.file=uimenu(hdl.dispkrig.h0,'label','&File','separator','on');
hdl.dispkrig.load_file=uimenu(hdl.dispkrig.file,'label','&Load Data','callback','file_browser(4,1);','separator','on');
hdl.dispkrig.save_file=uimenu(hdl.dispkrig.file,'label','&Save Data','callback','file_browser(5);','separator','on');
hdl.dispkrig.about_var=uimenu(hdl.dispkrig.file,'label','&Variable Structure','callback','edit variables.txt;','separator','on');
hdl.vario.quit=uimenu(hdl.dispkrig.file,'label','&Quit','callback','close_window(4)','separator','on');
%hdl.dispkrig.show_plot=uimenu(hdl.dispkrig.h0,'label','Show &Plot','callback','dispkrig(1)','separator','off');
hdl.dispkrig.track_line=uimenu(hdl.dispkrig.h0,'label','&Track Line');
hdl.dispkrig.trackline.c1=uimenu(hdl.dispkrig.track_line,'label','Color','callback','advanced_dispkrig(1,1)','separator','off','checked','on');
hdl.dispkrig.trackline.c2=uimenu(hdl.dispkrig.track_line,'label','Black/White','separator','off');
hdl.dispkrig.trackline.c2color1=uimenu(hdl.dispkrig.trackline.c2,'label','White','callback','advanced_dispkrig(1,2,1)','separator','off');
hdl.dispkrig.trackline.c2color2=uimenu(hdl.dispkrig.trackline.c2,'label','Black','callback','advanced_dispkrig(1,2,2)','separator','off');

hdl.dispkrig.trackline.c3=uimenu(hdl.dispkrig.track_line,'label','Value','separator','off');
%% color
hdl.dispkrig.trackline.c3color=uimenu(hdl.dispkrig.trackline.c3,'label','Color','separator','off');
hdl.dispkrig.trackline.c3color1=uimenu(hdl.dispkrig.trackline.c3color,'label','Yellow','callback','advanced_dispkrig(1,3,3,1)','separator','off','checked','off');
hdl.dispkrig.trackline.c3color2=uimenu(hdl.dispkrig.trackline.c3color,'label','Magenta','callback','advanced_dispkrig(1,3,2)','separator','off','checked','off');
hdl.dispkrig.trackline.c3color3=uimenu(hdl.dispkrig.trackline.c3color,'label','Cyan','callback','advanced_dispkrig(1,3,3,3)','separator','off','checked','off');
hdl.dispkrig.trackline.c3color4=uimenu(hdl.dispkrig.trackline.c3color,'label','Red','callback','advanced_dispkrig(1,3,3,4)','separator','off','checked','off');
hdl.dispkrig.trackline.c3color5=uimenu(hdl.dispkrig.trackline.c3color,'label','Green','callback','advanced_dispkrig(1,3,3,5)','separator','off','checked','off');
hdl.dispkrig.trackline.c3color6=uimenu(hdl.dispkrig.trackline.c3color,'label','Blue','callback','advanced_dispkrig(1,3,3,6)','separator','off','checked','off');
hdl.dispkrig.trackline.c3color7=uimenu(hdl.dispkrig.trackline.c3color,'label','White','callback','advanced_dispkrig(1,3,3,7)','separator','off','checked','off');
hdl.dispkrig.trackline.c3color8=uimenu(hdl.dispkrig.trackline.c3color,'label','Black','callback','advanced_dispkrig(1,3,3,8)','separator','off','checked','on');
%% fontsize
hdl.dispkrig.trackline.c3size=uimenu(hdl.dispkrig.trackline.c3,'label','Fontsize','separator','off');
hdl.dispkrig.trackline.c3size4=uimenu(hdl.dispkrig.trackline.c3size,'label','4','callback','advanced_dispkrig(1,3,4,4)','separator','off','checked','off');
hdl.dispkrig.trackline.c3size5=uimenu(hdl.dispkrig.trackline.c3size,'label','5','callback','advanced_dispkrig(1,3,4,5)','separator','off','checked','off');
hdl.dispkrig.trackline.c3size6=uimenu(hdl.dispkrig.trackline.c3size,'label','6','callback','advanced_dispkrig(1,3,4,6)','separator','off','checked','off');
hdl.dispkrig.trackline.c3size7=uimenu(hdl.dispkrig.trackline.c3size,'label','7','callback','advanced_dispkrig(1,3,4,7)','separator','off','checked','off');
hdl.dispkrig.trackline.c3size8=uimenu(hdl.dispkrig.trackline.c3size,'label','8','callback','advanced_dispkrig(1,3,4,8)','separator','off','checked','on');
hdl.dispkrig.trackline.c3size9=uimenu(hdl.dispkrig.trackline.c3size,'label','9','callback','advanced_dispkrig(1,3,4,9)','separator','off','checked','off');
hdl.dispkrig.trackline.c3size10=uimenu(hdl.dispkrig.trackline.c3size,'label','10','callback','advanced_dispkrig(1,3,4,10)','separator','off','checked','off');
hdl.dispkrig.trackline.c3size11=uimenu(hdl.dispkrig.trackline.c3size,'label','11','callback','advanced_dispkrig(1,3,4,11)','separator','off','checked','off');

hdl.dispkrig.trackline.c4=uimenu(hdl.dispkrig.track_line,'label','Error','separator','off');
%% color
hdl.dispkrig.trackline.c4color=uimenu(hdl.dispkrig.trackline.c4,'label','Color','separator','off');
hdl.dispkrig.trackline.c4color1=uimenu(hdl.dispkrig.trackline.c4color,'label','Yellow','callback','advanced_dispkrig(1,4,3,1)','separator','off','checked','off');
hdl.dispkrig.trackline.c4color2=uimenu(hdl.dispkrig.trackline.c4color,'label','Magenta','callback','advanced_dispkrig(1,4,3,2)','separator','off','checked','off');
hdl.dispkrig.trackline.c4color3=uimenu(hdl.dispkrig.trackline.c4color,'label','Cyan','callback','advanced_dispkrig(1,4,3,3)','separator','off','checked','off');
hdl.dispkrig.trackline.c4color4=uimenu(hdl.dispkrig.trackline.c4color,'label','Red','callback','advanced_dispkrig(1,4,3,4)','separator','off','checked','off');
hdl.dispkrig.trackline.c4color5=uimenu(hdl.dispkrig.trackline.c4color,'label','Green','callback','advanced_dispkrig(1,4,3,5)','separator','off','checked','off');
hdl.dispkrig.trackline.c4color6=uimenu(hdl.dispkrig.trackline.c4color,'label','Blue','callback','advanced_dispkrig(1,4,3,6)','separator','off','checked','off');
hdl.dispkrig.trackline.c4color7=uimenu(hdl.dispkrig.trackline.c4color,'label','White','callback','advanced_dispkrig(1,4,3,7)','separator','off','checked','off');
hdl.dispkrig.trackline.c4color8=uimenu(hdl.dispkrig.trackline.c4color,'label','Black','callback','advanced_dispkrig(1,4,3,8)','separator','off','checked','on');
%% fontsize
hdl.dispkrig.trackline.c4size=uimenu(hdl.dispkrig.trackline.c4,'label','Fontsize','separator','off');
hdl.dispkrig.trackline.c4size4=uimenu(hdl.dispkrig.trackline.c4size,'label','4','callback','advanced_dispkrig(1,4,4,4)','separator','off','checked','off');
hdl.dispkrig.trackline.c4size5=uimenu(hdl.dispkrig.trackline.c4size,'label','5','callback','advanced_dispkrig(1,4,4,5)','separator','off','checked','off');
hdl.dispkrig.trackline.c4size6=uimenu(hdl.dispkrig.trackline.c4size,'label','6','callback','advanced_dispkrig(1,4,4,6)','separator','off','checked','off');
hdl.dispkrig.trackline.c4size7=uimenu(hdl.dispkrig.trackline.c4size,'label','7','callback','advanced_dispkrig(1,4,4,7)','separator','off','checked','off');
hdl.dispkrig.trackline.c4size8=uimenu(hdl.dispkrig.trackline.c4size,'label','8','callback','advanced_dispkrig(1,4,4,8)','separator','off','checked','on');
hdl.dispkrig.trackline.c4size9=uimenu(hdl.dispkrig.trackline.c4size,'label','9','callback','advanced_dispkrig(1,4,4,9)','separator','off','checked','off');
hdl.dispkrig.trackline.c4size10=uimenu(hdl.dispkrig.trackline.c4size,'label','10','callback','advanced_dispkrig(1,4,4,10)','separator','off','checked','off');
hdl.dispkrig.trackline.c4size11=uimenu(hdl.dispkrig.trackline.c4size,'label','11','callback','advanced_dispkrig(1,4,4,11)','separator','off','checked','off');
hdl.dispkrig.trackline.c5=uimenu(hdl.dispkrig.track_line,'label','None','callback','advanced_dispkrig(1,5)','separator','off');
hdl.dispkrig.color_map=uimenu(hdl.dispkrig.h0,'label','&Color Map');
hdl.dispkrig.colormap.c1=uimenu(hdl.dispkrig.color_map,'label','hsv','callback','advanced_dispkrig(2,1)','separator','off');
hdl.dispkrig.colormap.c2=uimenu(hdl.dispkrig.color_map,'label','hot','callback','advanced_dispkrig(2,2)','separator','off');
hdl.dispkrig.colormap.c3=uimenu(hdl.dispkrig.color_map,'label','gray','callback','advanced_dispkrig(2,3)','separator','off');
hdl.dispkrig.colormap.c4=uimenu(hdl.dispkrig.color_map,'label','bone','callback','advanced_dispkrig(2,4)','separator','off');
hdl.dispkrig.colormap.c5=uimenu(hdl.dispkrig.color_map,'label','copper','callback','advanced_dispkrig(2,5)','separator','off');
hdl.dispkrig.colormap.c6=uimenu(hdl.dispkrig.color_map,'label','pink','callback','advanced_dispkrig(2,6)','separator','off');
hdl.dispkrig.colormap.c7=uimenu(hdl.dispkrig.color_map,'label','white','callback','advanced_dispkrig(2,7)','separator','off');
hdl.dispkrig.colormap.c8=uimenu(hdl.dispkrig.color_map,'label','flag','callback','advanced_dispkrig(2,8)','separator','off');
hdl.dispkrig.colormap.c9=uimenu(hdl.dispkrig.color_map,'label','lines','callback','advanced_dispkrig(2,9)','separator','off');
hdl.dispkrig.colormap.c10=uimenu(hdl.dispkrig.color_map,'label','colorcube','callback','advanced_dispkrig(2,10)','separator','off');
hdl.dispkrig.colormap.c11=uimenu(hdl.dispkrig.color_map,'label','jet','callback','advanced_dispkrig(2,11)','separator','off','checked','on');
hdl.dispkrig.colormap.c12=uimenu(hdl.dispkrig.color_map,'label','prism','callback','advanced_dispkrig(2,12)','separator','off');
hdl.dispkrig.colormap.c13=uimenu(hdl.dispkrig.color_map,'label','cool','callback','advanced_dispkrig(2,13)','separator','off');
hdl.dispkrig.colormap.c14=uimenu(hdl.dispkrig.color_map,'label','autumn','callback','advanced_dispkrig(2,14)','separator','off');
hdl.dispkrig.colormap.c15=uimenu(hdl.dispkrig.color_map,'label','spring','callback','advanced_dispkrig(2,15)','separator','off');
hdl.dispkrig.colormap.c16=uimenu(hdl.dispkrig.color_map,'label','winter','callback','advanced_dispkrig(2,16)','separator','off');
hdl.dispkrig.colormap.c17=uimenu(hdl.dispkrig.color_map,'label','summer','callback','advanced_dispkrig(2,17)','separator','off');
hdl.dispkrig.colormap.c18=uimenu(hdl.dispkrig.color_map,'label','customized color map','callback','advanced_dispkrig(2,18)','separator','on');

h2= uimenu('Parent',hdl.dispkrig.h0,'label','&Navigator');
h2a=uimenu(h2,'label','&Open','callback','figure(hdl.navigator.h0);');
h3= uimenu('Parent',hdl.dispkrig.h0,'label','&Load Data');
h3a= uimenu(h3,'label','&Open','callback','dataprepfig;');
h3b= uimenu(h3,'label','&Close','callback','close_window(1);');
h4=uimenu('Parent',hdl.dispkrig.h0,'label','&Variogram');
h4a= uimenu(h4,'label','&Open','callback','fit_vario_corfig;');
h4b= uimenu(h4,'label','&Close','callback','close_window(2);');
h5= uimenu('Parent',hdl.dispkrig.h0,'label','&Kriging');
h5a= uimenu(h5,'label','&Open','callback','krigingfig;');
h5b= uimenu(h5,'label','&Close','callback','close_window(3);');
h9= uimenu('Parent',hdl.dispkrig.h0,'label','&Quit');
h9a= uimenu(h9,'label','&Close','callback','close_window(4);');
h9b= uimenu(h9,'label','Quit &EasyKrig','callback','close all;');
hdl.dispkrig.status=1;

para.dispkrig.trackline.type_indx=1;
para.dispkrig.trackline.line_color=1;
para.dispkrig.colormap_indx=11;
para.dispkrig.num_of_contour=4;
para.dispkrig.digits_of_contour=3;
para.dispkrig.trackline.color_indx=8;
para.dispkrig.trackline.size_indx=8;
para.dispkrig.validation_model=1;
para.dispkrig.Qcheck=0;
para.dispkrig.JKcheck=0;
if para.status >= 1 
  if isfield(para.dataprep,'fileID')
  	set(hdl.dispkrig.fileID,'string',para.dataprep.fileID);
  	if isfield(para.dataprep,'transform_index')	
  	   if para.dataprep.transform_index > 1 
 	 	  set(hdl.dispkrig.transform,'value',1);
      end
  	end
  end
end

para.status=4;


color_map_list={'hsv        - Hue-saturation-value color map.', ...
    'hot        - Black-red-yellow-white color map.', ...
    'gray       - Linear gray-scale color map.', ...
    'bone       - Gray-scale with tinge of blue color map.', ...
    'copper     - Linear copper-tone color map.', ...
    'pink       - Pastel shades of pink color map.', ...
    'white      - All white color map.', ...
    'flag       - Alternating red, white, blue, and black color map.', ...
    'lines      - Color map with the line colors.', ...
    'colorcube  - Enhanced color-cube color map.', ...
    'jet        - Variant of HSV.', ...
    'prism      - Prism color map.', ...
    'cool       - Shades of cyan and magenta color map.', ...
    'autumn     - Shades of red and yellow color map.', ...
    'spring     - Shades of magenta and yellow color map.', ...
    'winter     - Shades of blue and green color map.', ...
    'summer     - Shades of green and yellow color map.', ...
    'customized colormap table'};
