function CVV=blk2blk(x1,y1,x2,y2,nx,ny,Lx,Ly,model,model_para)
%% function CVV=blk2blk(x1,y1,x2,y2,nx,ny,Lx,Ly,model,model_para)
%% computes the normalized covariance over a square block to a square block 
%% (x1,y1)  coordinates of the center of block 1
%% (x2,y2)  coordinates of the center of block 2
%% nx x ny   no. of elements of the block
%%  Lx,Ly     block size  
%%  model:  semi-variogram model index
%%  model_para: model parameters
% Author: Jim Ledwell, 10/97 Woods Hole Oceanographic Institution
% Revised by Dezhang Chu,   10-29-99

blk_x_res=Lx/nx;				% horizontal resolution within the block
blk_y_res=Ly/ny;				% horizontal resolution within the block
%% create block matrices 
xl1=linspace(x1-Lx/2+blk_x_res/2,x1+Lx/2-blk_x_res/2,nx);
yl1=linspace(y1-Ly/2+blk_y_res/2,y1+Ly/2-blk_y_res/2,n);
xl2=linspace(x2-Lx/2+blk_x_res/2,x2+Lx/2-blk_x_res/2,n);
yl2=linspace(y2-Ly/2+blk_y_res/2,y2+Ly/2-blk_y_res/2,n);

[X2,Y2]=meshgrid(xl2,yl2);
CVV=0;
for i=1:nx
   dX=xl1(i)-X2;
   for j=1:ny
     dY=yl1(j)-Y2;
     R=sqrt(dX.*dX + dY.*dY);
     A=variogrammodel(model,R,model_para);
     CVV=CVV+sum(sum(A));						% simple summation
   end
end
CVV=CVV/(nx*nx*ny*ny);
