function		batch_krig()
%% function		batch_krig()
%% Batch kriging on slected data files using current variogram/correlogram and kriging parameters
%%
%%  Kriging Software Package  version 2.0,   October 29, 1999
%%  Copyright (c) 1999, property of Dezhang Chu and Woods Hole Oceanographic
%%  Institution.  All Rights Reserved.
%%
%%  Modified on 2/4/00		to be able to include the last file on the filename list
%%									without CR at the end

global para hdl data
	
if ~isfield(para.vario,'nugt')
   message(1,'Need to set variogram/correlogram parameters for batch processing information');
   return;
end

if para.vario.nugt == 0 & para.vario.sill == 1 & para.vario.model == 13 ...
	& para.vario.lscl == 0.1 & para.vario.powr == 1.5 & para.vario.hole == 0
   message(1,'You may need to set variogram/correlogram parameters for batch processing information');
   return;
end

if para.krig.xmin == -1.0 & para.krig.xmax == 1.0 ...
   & para.krig.ymin == -1.0 & para.krig.ymax == 1.0
   message(1,'You may need to set kriging parameters for batch processing information');
   return;
end

if ~isfield(para.krig,'batch_data_file')
   message(1,'Need to provide a file that contains a list of filenames');
   return;
end
if ~isfield(para.krig,'batch_log_file')
   message(1,'Need to specify a log filename that record the batch processing information');
   return;
end

fid=fopen(para.krig.batch_data_file,'r');
if isempty(fid)
  return
end
para.krig.batch_file_proc=1;

if 0  %%%%%%%%%%%%%  beginning of obsolete program block %%%%%%%%%%%%%%%
F=fread(fid);
fname_array = setstr(F');
cr_indx=find(F == 10);


%%%%%%   modified on 2/5/00 to handle filename list with and without CR 
%%%%%%   at the end of the last line
para.krig.batch_filename_in=[];	% initialization
para.krig.batch_filename_out=[];
nr=length(cr_indx);				 
if max(cr_indx) ~= length(F)   
   cr_indx(nr+1)=length(F)+2;	 % without CR at the end of the line
end
%%%%%%%%			end of modification made on 2/5/00

ind1=1;
for i=1:length(cr_indx)
  ind2=cr_indx(i)-1;
  indx=ind1:ind2-1;
  fname_len(i)=ind2-ind1;
  para.krig.batch_filename_in(i,1:fname_len(i))=fname_array(indx);
  fname=filenametruncation(fname_array(indx));
  out_file=[para.krig.batch_out_dir fname '.mat'];    
  para.krig.batch_filename_out(i,1:length(out_file))=out_file;
  ind1=ind2+2;
end 
end 
%%%%%%%%%%%%%  end of obsolete  %%%%%%%%%%%%%%%

%%% get input filenames and set output filenames   3/2/00
k=0;
while 1
  line = fgetl(fid);
  if ~isstr(line), break, end
  k=k+1;
  fname_len(k)=length(line);
  para.krig.batch_filename_in(k,1:fname_len(k))=line;
  fname=filenametruncation(line);
  out_file=[para.krig.batch_out_dir fname '.mat'];    
  para.krig.batch_filename_out(k,1:length(out_file))=out_file;
end
fclose(fid);              

para.krig.bat_proc_time=0;
fid=fopen(para.krig.batch_log_file,'w');
for i=1:k
   para.krig.bat_proc_cnt=i;
   line1=sprintf('file #%3d',i);
   fprintf(fid,'%s\n',line1);
   fid1=fopen(para.krig.batch_filename_in(i,:),'r');
   if fid1 < 0
     line1=sprintf('input filename %s is not found',para.krig.batch_filename_in(i,:));
     message(1,line1);
   else
	  fclose(fid1);						% added on 2/5/00
     line2=sprintf('    input filename = %s',para.krig.batch_filename_in(i,:));    
     fprintf(fid,'%s\n',line2);
%% start data processing
     para.krig.data_file=para.krig.batch_filename_in(i,1:fname_len(i));
     indx=find(para.krig.data_file == '/' | para.krig.data_file == '\' | para.krig.data_file ==':');
     if ~isempty(indx)
        pindx=max(indx);
        filename=para.krig.data_file(pindx+1:length(para.krig.data_file));
     else
        filename=para.krig.data_file;
     end
	  truncated_filename=filenametruncation(filename);
	  set(hdl.krig.fileID,'string',truncated_filename);
	  para.dataprep.fileID=truncated_filename;
	  loaddatfile(2);			% load data file from kriging window
	  datachk(2);					% calling datachk.m from kriging window
     if ~isfield(para.dataprep,'transform_index') para.dataprep.transform_index=1;end
  	  data.in.tv=datatransform(1,data.in.v,para.dataprep.transform_index);	% Forward Data Transformation
     kriging;
     if ~isfield(para.dispkrig,'trackline')   %% added 3/2/00
			para.dispkrig.trackline.type_indx=1;
			para.dispkrig.trackline.line_color=1;
			para.dispkrig.colormap_indx=11;
			para.dispkrig.num_of_contour=4;
			para.dispkrig.digits_of_contour=3;
			para.dispkrig.trackline.color_indx=8;
			para.dispkrig.trackline.size_indx=8;
			para.dispkrig.validation_model=1;
			para.dispkrig.Qcheck=0;
			para.dispkrig.JKcheck=0;
     end
     line3=sprintf('    output filename = %s',para.krig.batch_filename_out(i,:));
     cmd=['save ''' para.krig.batch_filename_out(i,:) ''' para data'];
     eval(cmd);
     fprintf(fid,'%s\n',line3);
  end
end
fclose(fid);
