function		batch_krig()
%% function		batch_krig()
%% Batch kriging on slected data files using current variogram/correlogram and kriging parameters
%%
%%  Kriging Software Package  version 2.0,   October 29, 1999
%%  Copyright (c) 1999, property of Dezhang Chu and Woods Hole Oceanographic
%%  Institution.  All Rights Reserved.

global para hdl data
	
if ~isfield(para.vario,'nugt')
   message(1,'Need to set variogram/correlogram parameters for batch processing information');
   return;
end

if para.vario.nugt == 0 & para.vario.sill == 1 & para.vario.model == 13 ...
	& para.vario.lscl == 0.1 & para.vario.powr == 1.5 & para.vario.hole == 0
   message(1,'You may need to set variogram/correlogram parameters for batch processing information');
   return;
end

if para.krig.xmin == -1.0 & para.krig.xmax == 1.0 ...
   & para.krig.ymin == -1.0 & para.krig.ymax == 1.0
   message(1,'You may need to set kriging parameters for batch processing information');
   return;
end

if ~isfield(para.krig,'batch_data_file')
   message(1,'Need to provide a file that contains a list of filenames');
   return;
end
if ~isfield(para.krig,'batch_log_file')
   message(1,'Need to specify a log filename that record the batch processing information');
   return;
end

fid=fopen(para.krig.batch_data_file,'r');
if isempty(fid)
  return
end
para.krig.batch_file_proc=1;
F=fread(fid);
fname_array = setstr(F');
cr_indx=find(F == 10);
ind1=1;
for i=1:length(cr_indx)
  ind2=cr_indx(i)-1;
  indx=ind1:ind2-1;
  fname_len(i)=ind2-ind1;
  para.krig.batch_filename_in(i,1:fname_len(i))=fname_array(indx);
  fname=filenametruncation(fname_array(indx));
  out_file=[para.krig.batch_out_dir fname '.mat'];    
  para.krig.batch_filename_out(i,1:length(out_file))=out_file;
  ind1=ind2+2;
end 
fclose(fid);              

para.krig.bat_proc_time=0;
fid=fopen(para.krig.batch_log_file,'w');
for i=1:length(cr_indx)
   para.krig.bat_proc_cnt=i;
   line1=sprintf('file #%3d',i);
   fprintf(fid,'%s\n',line1);
   fid1=fopen(para.krig.batch_filename_in(i,:),'r');
   if fid1 < 0
     line2=sprintf('    input filename = %s is not found',para.krig.batch_filename_in(i,:));
   else
     line2=sprintf('    input filename = %s',para.krig.batch_filename_in(i,:));    
     fprintf(fid,'%s\n',line2);
%% start data processing
     para.krig.data_file=para.krig.batch_filename_in(i,1:fname_len(i));
     indx=find(para.krig.data_file == '/' | para.krig.data_file == '\' | para.krig.data_file ==':');
     if ~isempty(indx)
        pindx=max(indx);
        filename=para.krig.data_file(pindx+1:length(para.krig.data_file));
     else
        filename=para.krig.data_file;
     end
	  truncated_filename=filenametruncation(filename);
	  set(hdl.krig.fileID,'string',truncated_filename);
	  para.dataprep.fileID=truncated_filename;
	  loaddatfile(2);			% load data file from kriging window
	  datachk(2);					% calling datachk.m from kriging window
     if ~isfield(para.dataprep,'transform_index') para.dataprep.transform_index=1;end
  	  data.in.tv=datatransform(1,data.in.v,para.dataprep.transform_index);	% Forward Data Transformation
     kriging;
     line3=sprintf('    output filename = %s',para.krig.batch_filename_out(i,:));
     cmd=['save ' para.krig.batch_filename_out(i,:) ' para data'];
     eval(cmd);
     fprintf(fid,'%s\n',line3);
  end
end
fclose(fid);
