function			cross_validation(opt)
% function			cross_validation(opt)
% performs cross validation computation
% opt = 	1				double kriging
%			2				Jackknife
%			3				Q1 cross validation
%			4				Q2 cross validation

%%  Kriging Software Package  version 2.0,   October 29, 1999
%%  Copyright (c) 1999, property of Dezhang Chu and Woods Hole Oceanographic
%%  Institution.  All Rights Reserved.

global	data para hdl

if ~isfield(para,'vario')
    message(1,'Need to performing kriging first!!');
   return
elseif ~isfield(para.vario,'model')
   message(1,'Need to performing kriging first!!');
   return
end

vmod=para.vario.model;
if para.vario.corr == 1
  vmod = -vmod;
end
model_para=[para.vario.nugt para.vario.sill para.vario.lscl para.vario.powr para.vario.hole];

%% anisotrophy parameters
anisotropy_para=[para.vario.angle para.vario.ratio];

%% kriging parameters
mod_opt=para.krig.model;
srad=para.krig.srad;
kmin=para.krig.kmin;
kmax=para.krig.kmax;
blk_opt=para.krig.scheme;
blknx=para.krig.blk_nx;
blkny=para.krig.blk_ny;
elim=para.krig.elim;
dx=para.krig.dx;
dy=para.krig.dy;
EPS=para.krig.eps;
krig_para=[blk_opt,blknx,blkny,srad,kmin,kmax,elim,dx,dy,EPS,anisotropy_para];
x=data.in.x;
y=data.in.y;
var=data.in.tv;
msg1='Cross-Validation in progress, ...';
msg2=' ';
nmin=8;						% standard for displaying time elapse

tic
switch	opt
	case  1			% double kriging - default
	 para.dispkrig.validation_model=1;
	 dispkrig(4);
	case	2			% jackknife
	 if para.dispkrig.JKcheck == 0
		if para.dataprep.transform_index > 1 & ~get(hdl.dispkrig.transform,'value')	% inverse transformation
			var=datatransform(2,data.in.tv);
		else													% transformed data
			var=data.in.tv;
		end
		n=length(x);
		if n >= nmin hmsg=message(2,msg1,' ');end
      Ijk(1)=var(1);
		nv=n-mod_opt;
		nv_cnt=max(1,round(0.01*nv));
		for i=2:n
			j=i-mod_opt;
  			if rem(j,nv_cnt) == 0 
     			percent=sprintf('   %g percent done in %g sec.', floor(100*j/nv),round(toc));
     		   if n >= nmin message(4,percent,' ',hmsg);drawnow; end
  			end
			xc=x(i);yc=y(i);
			xi=[x(1:i-1); x(i+1:n)];yi=[y(1:i-1); y(i+1:n)];var_in=[var(1:i-1); var(i+1:n)];
			[var_out,err_krig]=krig(mod_opt,xc,yc,xi,yi,var_in,krig_para,vmod,model_para);
			Ijk(i)=var_out;
	   end
		data.out.krig.Ijk=Ijk(:);
		if n > nmin close(hmsg);end
	 end
	 para.dispkrig.validation_model=2;
	 para.dispkrig.JKcheck=1;
	 dispkrig(4);	 
	case  3			% Q-1
	 if para.dispkrig.Qcheck == 0
      if ~isfield(data.out,'vario')  % need to call variogram program to compute variance
			variogram;
      end
		sigma0=sqrt(data.out.vario.c0);
		n=length(x);
		if n >= nmin hmsg=message(2,msg1,' ');drawnow;end
		nv=n-mod_opt;
		nv_cnt=max(1,round(0.01*nv));
		for i=mod_opt+1:n
			j=i-mod_opt;
  			if rem(j,nv_cnt) == 0 
     			percent=sprintf('   %g percent done in %g sec.', floor(100*j/nv),round(toc));
     		   if n >= nmin message(4,percent,' ',hmsg);drawnow; end
  			end
			xc=x(i);yc=y(i);
			xi=x(1:i-1);yi=y(1:i-1);var_in=var(1:i-1);
			[var_out,err_krig]=krig(mod_opt,xc,yc,xi,yi,var_in,krig_para,vmod,model_para);
			if err_krig < 0 err_krig=nan;end
		  	ek(i-mod_opt)=(var(i)-var_out)/(sigma0*sqrt(err_krig));
			errk(i-mod_opt)=err_krig;
	   end
		data.out.krig.q1=mean_nan(ek);
		data.out.krig.ek=ek;
		if n > nmin close(hmsg);end
	 else
        data.out.krig.q1=mean_nan(data.out.krig.ek);
	 end
	 para.dispkrig.validation_model=3;
	 para.dispkrig.Qcheck=1;
	 dispkrig(4);
	case  4			% Q-2
	 if para.dispkrig.Qcheck == 0
      if ~isfield(data.out,'vario')  % need to call variogram program to compute variance
			variogram;
      end
		sigma0=sqrt(data.out.vario.c0);
		n=length(x);
		if n >= nmin hmsg=message(2,msg1,' ');drawnow;end
		nv=n-mod_opt;
		nv_cnt=max(1,round(0.01*nv));
		for i=mod_opt+1:n
			j=i-mod_opt;
  			if rem(j,nv_cnt) == 0 
     			percent=sprintf('   %g percent done in %g sec.', floor(100*j/nv),round(toc));
     		   if n >= nmin message(4,percent,' ',hmsg);drawnow; end
  			end
			xc=x(i);yc=y(i);
			xi=x(1:i-1);yi=y(1:i-1);var_in=var(1:i-1);
			[var_out,err_krig]=krig(mod_opt,xc,yc,xi,yi,var_in,krig_para,vmod,model_para);
			if err_krig < 0 err_krig=nan;end
			ek(i-mod_opt)=(var(i)-var_out)/(sigma0*sqrt(err_krig));
			errk(i-mod_opt)=err_krig;
	   end
		para.dispkrig.Qcheck=1;
		data.out.krig.q2=mean_nan(ek.^2);
		data.out.krig.ek=ek;
		if n > nmin close(hmsg);end
	 else
		data.out.krig.q2=mean_nan(data.out.krig.ek.^2);
	 end
	 para.dispkrig.validation_model=4;
	 dispkrig(4);
end