function			dispkrig(opt,single_plot_index)
% function			dispkrig(opt)
% display kriging results
%%	opt = 1				redraw all figures
%% 		2				change track-lines
%% 		3				change colormap of images
%% 		4				display results of cross-validation
%%			5				single plot
%	single_plot_index
%%			1				seperate kriging map 
%%			2				seperate kriging variance map 
%%			3				separate cross validation curve
%%
%%  EasyKrig Software Package  version 2.0,   October 1, 1999
%%  Copyright (c) 1999, property of Dezhang Chu and Woods Hole Oceanographic
%%  Institution.  All Rights Reserved.

global	data para hdl

DEG2RAD=pi/180;
if ~isfield(data,'in')
  message(1,'Need to load input data !!');
  return
end
    
xs=data.in.x*para.dataprep.x_norm./para.dataprep.latlonfac+para.dataprep.x_offset;
ys=data.in.y*para.dataprep.y_norm+para.dataprep.y_offset;
if ~isfield(data,'out')
  message(1,'Need to run kriging first !!');
  return
elseif ~isfield(data.out,'krig')
  message(1,'Need to run kriging first !!');
  return
end

xg=data.out.krig.xg;
yg=data.out.krig.yg;
[Xg,Yg]=meshgrid(xg,yg);
Yg=Yg*para.dataprep.y_norm+para.dataprep.y_offset;

if para.dataprep.file_col1_index <= 2 & para.dataprep.file_col2_index <= 2   % Long/Lat
  Xg=Xg./cos(Yg*DEG2RAD);
end
Xg=Xg*para.dataprep.x_norm+para.dataprep.x_offset;
xg=data.out.krig.xg*para.dataprep.x_norm+para.dataprep.x_offset;
yg=data.out.krig.yg*para.dataprep.y_norm+para.dataprep.y_offset;
xgmin=min(min(Xg));
xgmax=max(max(Xg));
ygmin=para.krig.ymin*para.dataprep.y_norm+para.dataprep.y_offset;
ygmax=para.krig.ymax*para.dataprep.y_norm+para.dataprep.y_offset;

if para.dataprep.transform_index > 1	% data have been transformed
	if ~get(hdl.dispkrig.transform,'value')		% inverse transformation
		var=datatransform(2,data.in.tv);
		Ig=datatransform(2,real(data.out.krig.Ig));
		Is=datatransform(2,real(data.out.krig.Is));
		set(hdl.dispkrig.transform,'value',0)
	else													% transformed data
		var=data.in.tv;
		Ig=real(data.out.krig.Ig);
		Is=real(data.out.krig.Is);
		set(hdl.dispkrig.transform,'value',1)
	end
else												% data have not been transformation 
  var=data.in.tv;
  Ig=real(data.out.krig.Ig);
  Is=real(data.out.krig.Is);
  set(hdl.dispkrig.transform,'enable','off')
end

eg=real(data.out.krig.eg);
nx=data.out.krig.nx;
ny=data.out.krig.ny;
Cg=reshape(Ig,ny,nx);
Eg=reshape(eg,ny,nx);
markersize=para.dispkrig.markersize;
clr_max=64;
TrackLineType=para.dispkrig.trackline.type_indx;
TrackLineColor=para.dispkrig.trackline.line_color;
vKrig=auto_contour(Ig,para.dispkrig.num_of_contour,para.dispkrig.digits_of_contour);
vErr=auto_contour(eg,para.dispkrig.num_of_contour,para.dispkrig.digits_of_contour);

%% kriging map

%%% plot kriging map
delete(findobj(hdl.dispkrig.h0,'Tag','colorbar1'));
delete(findobj(hdl.dispkrig.h0,'Tag','dispkrigAxes1'));
hdl.dispkrig.axes1 = axes('Parent',hdl.dispkrig.h0, ...
	'Color',[1 1 1], ...
	'Position',[0.1 0.55 0.40 0.35]);
elim=str2num(get(hdl.dispkrig.err_lvl,'string'));
Cg1=Cg;
indx_err=find(Eg >= elim);
Cg1(indx_err)=nan*ones(size(indx_err));
pcolor(Xg,Yg,Cg1);shading interp
axis([ xgmin xgmax ygmin ygmax])
set(hdl.dispkrig.axes1,'Tag','dispkrigAxes1');

hdl.dispkrig.colorbar1=colorbar('horiz');
set(hdl.dispkrig.colorbar1,'Tag','colorbar1');
hold on
%clr=min(max(floor(clr_max*(var-min(var))/(max(var)-min(var))),0)+1,clr_max);
Cgmax=max(max(Cg));
Cgmin=min(min(Cg));
clr=min(max(floor(clr_max*(var-Cgmin)/(Cgmax-Cgmin)),0)+1,clr_max);
cmap=colormap;
n=length(xs);
inc=max(1,round(n/1600));
hold on
track_color='ymcrgbwk';
clr_indx=TrackLineColor+6;
switch TrackLineType
	case 1			% color-coded tracklines
 		for i=1:inc:n
   		plot(xs(i),ys(i),'.','color',cmap(clr(i),:),'markersize',markersize);
 		end
   case 2		% black/white tracklines
  		if n >= 100
    		hxy=plot(xs,ys,['.' track_color(clr_indx)],'linewidth',2.5);
  		else
    		hxy=plot(xs,ys,['.' track_color(clr_indx)],'markersize',markersize);
  		end
	case 3		% attribute values
  		hxy=plot(xs,ys,['.' track_color(clr_indx)],'markersize',markersize);
  		htxt=text(xs,ys,num2str(var));
  		set(htxt,'fontsize',para.dispkrig.trackline.size_indx,'color',track_color(para.dispkrig.trackline.color_indx));
	case 4		% difference between observed and kriged attribute values 
  		hxy=plot(xs,ys,['.' track_color(clr_indx)],'markersize',markersize);
  		htxt=text(xs,ys,num2str(var-Is));
  		set(htxt,'fontsize',para.dispkrig.trackline.size_indx,'color',track_color(para.dispkrig.trackline.color_indx));
end
if ~isempty(vKrig)
  if isnan(vKrig) 
    [c,H]=contour(Xg,Yg,Cg,'k');
  else
    [c,H]=contour(Xg,Yg,Cg,vKrig,'k');
  end
  hh=clabel(c,H);
end

  if para.dataprep.file_col1_index <= 2 | para.dataprep.file_col2_index <= 2	% either x or y is Lat or Long
     ntick=4;
     [xinc,xdits,yinc,ydits]=get_ninc(hdl.dispkrig.axes1,ntick);
	  if para.dataprep.file_col1_index <= 2
       mapax(xinc,xdits,yinc,ydits,hdl.dispkrig.axes1,1);		% x-axis label
	  end
	  if para.dataprep.file_col2_index <= 2
       mapax(xinc,xdits,yinc,ydits,hdl.dispkrig.axes1,2);		% y-axis label
	  end
     tick_len=size(get(hdl.dispkrig.axes1,'yticklabel'),2);
     switch tick_len
       case 9
			set(hdl.dispkrig.axes1,'fontsize',9)
       case 10
			set(hdl.dispkrig.axes1,'fontsize',8)
     end
  end
  title([para.dataprep.xlabel ' -- KRIGING MAP'],'fontsize',10,'fontweight','bold')
  ylabel(para.dataprep.ylabel,'fontsize',10,'fontweight','bold')
  if get(hdl.dispkrig.xdir,'value');
	  set(hdl.dispkrig.axes1,'xdir','reverse');
  else
     set(hdl.dispkrig.axes1,'xdir','normal');
  end
  if get(hdl.dispkrig.ydir,'value');
	  set(hdl.dispkrig.axes1,'ydir','reverse');
  else
     set(hdl.dispkrig.axes1,'ydir','normal');
  end

if opt ~= 2
%%% kriging variance map
delete(findobj(hdl.dispkrig.h0,'Tag','colorbar2'))
delete(findobj(hdl.dispkrig.h0,'Tag','dispkrigAxes2'));

hdl.dispkrig.axes2 = axes('Parent',hdl.dispkrig.h0, ...
	'Position',[0.55 0.55 0.40 0.35], ...
	'Color',[1 1 1]);

hxy=pcolor(Xg,Yg,Eg);shading interp;
set(hdl.dispkrig.axes2,'Tag','dispkrigAxes2');

if ~isempty(vErr)
  hold on
  if isnan(vErr)
    [c,H]=contour(Xg,Yg,Eg,'k');
  else
    [c,H]=contour(Xg,Yg,Eg,vErr,'k');
  end
  hh=clabel(c,H);
end
hold on

if TrackLineType < 3
  if n >= 1000
    hxy=plot(xs,ys,'w','linewidth',2.5);
  else
   hxy=plot(xs,ys,'.w','markersize',markersize);
  end
end
hdl.dispkrig.colorbar2=colorbar('horiz');
set(hdl.dispkrig.colorbar2,'Tag','colorbar2');

axis([ xgmin xgmax ygmin ygmax])
fcmap=colormap;
hold off

  if para.dataprep.file_col1_index <= 2 	% x  Lat or Long
     mapax(xinc,xdits,yinc,ydits,hdl.dispkrig.axes2,1);		% x-axis label
     tick_len=size(get(hdl.dispkrig.axes1,'yticklabel'),2);
	  set(hdl.dispkrig.axes2,'YTickLabel',[]);
     switch tick_len
       case 9
			set(hdl.dispkrig.axes2,'fontsize',9)
       case 10
			set(hdl.dispkrig.axes2,'fontsize',8)
     end
  end
  title('NORMALIZED KRIGING VARIANCE','fontsize',10,'fontweight','bold')
  if get(hdl.dispkrig.xdir,'value');
	  set(hdl.dispkrig.axes2,'xdir','reverse');
  else
     set(hdl.dispkrig.axes2,'xdir','normal');
  end
  if get(hdl.dispkrig.ydir,'value');
	  set(hdl.dispkrig.axes2,'ydir','reverse');
  else
     set(hdl.dispkrig.axes2,'ydir','normal');
  end

end								% opt ~= 2 ends

if opt == 1 | opt == 4
%% comparison
	delete(findobj(hdl.dispkrig.h0,'Tag','dispkrigAxes3'));
	hdl.dispkrig.axes3 = axes('Parent',hdl.dispkrig.h0, ...
		'Position',[0.1 0.1 0.40 0.35], ...
		'Color',[1 1 1]);
 	switch	para.dispkrig.validation_model 
		case 1					% double kriging
			set(hdl.dispkrig.validationmodel,'value',1);
			sta=1:length(var);
			plot(sta,var,'-o',sta,Is,'+-r');
			hh1=legend('Observation','Prediction',0);
			set(hh1,'fontsize',10)
			hx=xlabel('SAMPLE NUMBER');
			hy=ylabel('OBSERVATION AND PREDICTION');
			ht=title(['<z - z*> = ' sprintf('%g',mean_nan(var-Is)) '        \sigma = ' sprintf('%g',std_nan(var-Is))]);
			set([hx hy ht],'fontweight','bold')
		case 2		% JackKnife
			set(hdl.dispkrig.validationmodel,'value',2);
			Ijk=data.out.krig.Ijk;
			sta=1:length(var);
			plot(sta,var,'-o',sta,Ijk,'+-r');
			hh1=legend('Observation','Prediction',0);
			set(hh1,'fontsize',10)
			hx=xlabel('SAMPLE NUMBER');
			hy=ylabel('OBSERVATION AND PREDICTION');
			ht=title(['<z - z*> = ' sprintf('%g',mean_nan(var-Ijk)) '        \sigma = ' sprintf('%g',std_nan(var-Ijk))]);
			set([hx hy ht],'fontweight','bold')			
		case 3 		% Q-1
			set(hdl.dispkrig.validationmodel,'value',3);
			nq=2;
			n=length(xs)-para.krig.model;
	   	[x,fq,Qrej,fr]=pdf_func(para.dispkrig.validation_model,n);		  
			plot(x,fq,'m','linewidth',2.0)
			hold on
			plot(-Qrej*ones(1,2),[0 fr],'k',Qrej*ones(1,2),[0 fr],'k','linewidth',2.0);
			ht=text(-Qrej+0.02,0.5*fr,'Accept Region');
			if data.out.krig.q1 <= max(x) & data.out.krig.q1 >= min(x)
		   	plot(data.out.krig.q1*ones(1,nq),linspace(0,max(fq),nq),'-r','linewidth',1.5);
				hdt=text(data.out.krig.q1+0.02,0.8*max(fq),'Computed Q_1');
				set(hdt,'fontsize',8,'fontweight','bold');
			end
			title(sprintf('Q1 = %g',data.out.krig.q1),'fontweight','bold')
			hold off
			hx=xlabel('Q_1');
			hy=ylabel('PDF(Q_1)');
			set([hx hy ht],'fontweight','bold')
		case 4 		% Q-2
			set(hdl.dispkrig.validationmodel,'value',4);
			nq=2;
			n=length(xs)-para.krig.model;
	   	[x,fq,Qrej,fr]=pdf_func(para.dispkrig.validation_model,n);		  
			plot(x,fq,'m','linewidth',2.0)
			hold on
			plot(Qrej(1)*ones(1,2),[0 fr(1)],'k',Qrej(2)*ones(1,2),[0 fr(2)],'k','linewidth',2.0);
			ht=text(Qrej(1)+0.1,0.5*fr(1),'Accept Region');
			if data.out.krig.q2 <= max(x) & data.out.krig.q2 >= min(x)
		   	plot(data.out.krig.q2*ones(1,nq),linspace(0,max(fq),nq),'-r','linewidth',1.5);
				hdt=text(data.out.krig.q2+0.02,0.8*max(fq),'Computed Q_2');
				set(hdt,'fontsize',8,'fontweight','bold');
			end
			title(sprintf('Q2 = %g',data.out.krig.q2),'fontweight','bold')
			hold off
			hx=xlabel('Q_2');
			hy=ylabel('PDF(Q_2)');
			set([hx hy ht],'fontweight','bold')
	end
	set(hdl.dispkrig.axes3,'Tag','dispkrigAxes3');
end
if nargin == 2
  single_plot;
  return;
end

para.dispkrig.vCg=vKrig;
para.dispkrig.vEg=vErr;
data.out.krig.Xg=Xg;
data.out.krig.Yg=Yg;
data.out.krig.Cg=Cg;
if opt ~=2 data.out.krig.Eg=Eg; end
para.status=4.5;
