function fig = krigingfig()
%% function fig = krigingfig()
%%  opens the kriging window
%%
%%  EasyKrig Software Package  version 2.0,   October 1, 1999
%%  Copyright (c) 1999, property of Dezhang Chu and Woods Hole Oceanographic
%%  Institution.  All Rights Reserved.

global hdl data para color

grey=color.grey;
dark_grey=color.dark_grey;
blue=color.blue;

if ~isempty(findobj('type','figure','Tag','Kriging')) 
  figure(hdl.krig.h0);
  return
end

hdl.krig.h0 = figure('Units','normalized', ...
	'Color',[0.8 0.8 0.8], ...
	'Name','EasyKrig 2.0 -- Kriging', ...
	'Position',hdl.window_position, ...
	'Tag','Kriging');

%% FILE ID
hdl.krig.fileID = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'FontWeight','bold', ...
	'ForegroundColor',[0 0 0.5], ...
	'Position',[0.27 0.95 0.48 0.03], ...
	'String',' ', ...
	'Style','text', ...
	'Tag','KrigFileID');

%% Coordinate frame
x00=0.11;y00=0.54;Yf=.33;
Lvarstr=0.18;Lvalue=0.08;Lslider=0.15;dx=0.005;
Ly=hdl.object.edit_w;dy=0.05;
x0=0.12;y0=y00+Yf-dy-0.01;

h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Position',[x00 y00 0.35 Yf], ...
	'Style','frame', ...
	'Tag','FrmCoord');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ForegroundColor',[0 0 1], ...
	'Position',[x00+0.05 y00+Yf-0.015 0.2 0.04], ...
	'String','Coordinates', ...
	'Style','text');
%% xmin
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','right', ...
	'Position',[x0 y0 Lvarstr Ly], ...
	'String','Mininum Horizontal', ...
	'Style','text', ...
	'Tag','xminlab');
hdl.krig.xmin = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+dx y0 Lvalue Ly], ...
	'String',' ', ...
	'Style','edit', ...
	'Tag','xmin');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(1)', ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lvalue+2*dx,y0,Ly,Ly], ...
	'String','?', ...
	'Tag','XminHelp');
%% xmax
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','right', ...
	'Position',[x0 y0-dy Lvarstr Ly], ...
	'String','Maximum Horizontal', ...
	'Style','text', ...
	'Tag','xmaxlab');
hdl.krig.xmax = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+dx y0-dy Lvalue Ly], ...
	'String',' ', ...
	'Style','edit', ...
	'Tag','xmax');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(2)', ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lvalue+2*dx,y0-dy,Ly,Ly], ...
	'String','?', ...
	'Tag','XmaxHelp');
%% horizontal resolution delta x
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','right', ...
	'Position',[x0 y0-2*dy Lvarstr Ly], ...
	'String','Horizontal Resolution', ...
	'Style','text', ...
	'Tag','xdellab');
hdl.krig.dx = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+dx y0-2*dy Lvalue Ly], ...
	'String',' ', ...
	'Style','edit', ...
	'Tag','dx');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(3)', ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lvalue+2*dx,y0-2*dy,Ly,Ly], ...
	'String','?', ...
	'Tag','DxHelp');

%% ymin
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','right', ...
	'Position',[x0 y0-3*dy Lvarstr Ly], ...
	'String','Mininum Vertical', ...
	'Style','text', ...
	'Tag','yminlab');
hdl.krig.ymin = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+dx y0-3*dy Lvalue Ly], ...
	'String',' ', ...
	'Style','edit', ...
	'Tag','ymin');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(4)', ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lvalue+2*dx,y0-3*dy,Ly,Ly], ...
	'String','?', ...
	'Tag','YminHelp');
%% ymax
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','right', ...
	'Position',[x0 y0-4*dy Lvarstr Ly], ...
	'String','Maximum Vertical', ...
	'Style','text', ...
	'Tag','ymaxlab');
hdl.krig.ymax = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+dx y0-4*dy Lvalue Ly], ...
	'String',' ', ...
	'Style','edit', ...
	'Tag','ymax');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(5)', ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lvalue+2*dx,y0-4*dy,Ly,Ly], ...
	'String','?', ...
	'Tag','YmaxHelp');
%% vertical resolution dy
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','right', ...
	'Position',[x0 y0-5*dy Lvarstr Ly], ...
	'String','Vertical Resolution', ...
	'Style','text', ...
	'Tag','ydellab');
hdl.krig.dy = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+dx y0-5*dy Lvalue Ly], ...
	'String',' ', ...
	'Style','edit', ...
	'Tag','dy');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(6)', ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lvalue+2*dx,y0-5*dy,Ly,Ly], ...
	'String','?', ...
	'Tag','DyHelp');

%% Kriging parameters
%% Coordinate frame
x00=0.51;y00=0.32;Yf=.58;
Lvarstr=0.1;Lvalue=0.08;Lpopupmenu=0.22;dx=0.005;
Ly=hdl.object.edit_w;
dy=0.05;
x0=0.52;y0=y00+Yf-dy;

h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Position',[x00 y00+0.1 0.40 Yf-0.1], ...
	'Style','frame', ...
	'Tag','FrmModelPara');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ForegroundColor',[0 0 1], ...
	'Position',[x00+0.08 y00+Yf-0.005 0.25 Ly], ...
	'String','Kriging Parameters', ...
	'Style','text');
%%% krig model
model_str={'1.  Objective Analysis','2.  Ordinary Kriging','3.  Universal Kriging (linear drift)'};
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'HorizontalAlignment','center', ...
	'FontWeight','bold', ...
	'Position',[x0+2*dx y0-0.004 Lvarstr Ly], ...
	'String',' Model', ...
	'Style','text');
hdl.krig.model = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'Position',[x0+3*dx+Lvarstr y0 Lpopupmenu Ly], ...
	'String',model_str, ...
	'Style','popupmenu', ...
	'Tag','krigModel');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(7)', ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lpopupmenu+4*dx y0 Ly Ly], ...
	'String','?', ...
	'Tag','KrigModelListHelp');

%%% krig scheme
model_str={'1.  Point to Point','2.  Point to Block'};
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'HorizontalAlignment','center', ...
	'FontWeight','bold', ...
	'Position',[x0+2*dx y0-0.004-dy Lvarstr Ly], ...
	'String',' Scheme', ...
	'Style','text');
hdl.krig.scheme = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'Position',[x0+3*dx+Lvarstr y0-dy Lpopupmenu Ly], ...
	'String',model_str, ...
	'Style','popupmenu', ...
	'Tag','krigScheme');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(8)', ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lpopupmenu+4*dx y0-dy Ly Ly], ...
	'String','?', ...
	'Tag','KrigSchemeHelp');
%% block size
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Position',[x0+Lvarstr y0-2*dy Lslider Ly], ...
	'String','Horizontal Block Size', ...
	'Style','text');
hdl.krig.blk_nx = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lslider y0-2*dy Lvalue+dx Ly], ...
	'String',' ', ...
	'Style','edit', ...
	'Tag','Krigblk_nx');
hdl.krig.blkxhelp = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(9)', ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lslider+Lvalue+2*dx y0-2*dy Ly Ly], ...
	'String','?', ...
	'Tag','KrigBlknxHelp');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Position',[x0+Lvarstr y0-3*dy Lslider Ly], ...
	'String','Vertical Block Size', ...
	'Style','text');
hdl.krig.blk_ny = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lslider y0-3*dy Lvalue+dx Ly], ...
	'String',' ', ...
	'Style','edit', ...
	'Tag','Krigblk_ny');
hdl.krig.blkyhelp = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(10)', ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lslider+Lvalue+2*dx y0-3*dy Ly Ly], ...
	'String','?', ...
	'Tag','KrigBlknyHelp');
%% kriging Parameters
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','left', ...
	'Position',[x0+2*dx y0-4.3*dy Lvarstr Ly], ...
	'String','Parameters', ...
	'Style','text');
%% search radius
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Position',[x0+Lvarstr y0-5*dy Lslider Ly], ...
	'String','Search Radius', ...
	'Style','text');
hdl.krig.srad = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lslider y0-5*dy Lvalue+dx Ly], ...
	'String','', ...
	'Style','edit', ...
	'Tag','srad');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(11)', ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lslider+Lvalue+2*dx y0-5*dy Ly Ly], ...
	'String','?', ...
	'Tag','KrigSradHelp');
%% minimum krig points
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Position',[x0+Lvarstr y0-6*dy Lslider Ly], ...
	'String','Min. Kriging Points', ...
	'Style','text');
hdl.krig.kmin = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lslider y0-6*dy Lvalue+dx Ly], ...
	'String',' ', ...
	'Style','edit', ...
	'Tag','kmin');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(12)', ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lslider+Lvalue+2*dx y0-6*dy Ly Ly], ...
	'String','?', ...
	'Tag','KrigkminHelp');
%% maximum krig points
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Position',[x0+Lvarstr y0-7.0*dy Lslider Ly], ...
	'String','Max. Kriging Points', ...
	'Style','text');
hdl.krig.kmax = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lslider y0-7*dy Lvalue+dx Ly], ...
	'String',' ', ...
	'Style','edit', ...
	'Tag','kmax');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(13)', ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lslider+Lvalue+2*dx y0-7*dy Ly Ly], ...
	'String','?', ...
	'Tag','KrigkmaxHelp');
%% relative error limit
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Position',[x0+Lvarstr y0-8.0*dy Lslider Ly], ...
	'String','Relative Error', ...
	'Style','text');
hdl.krig.elim = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lslider y0-8.0*dy Lvalue+dx Ly], ...
	'String','', ...
	'Style','edit', ...
	'Tag','elim');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(14)', ...
	'FontWeight','bold', ...
	'Position',[x0+Lvarstr+Lslider+Lvalue+2*dx y0-8.0*dy Ly Ly], ...
	'String','?', ...
	'Tag','KrigelimHelp');

%% Load/Save Parameter file frame
x00=0.11;y00=0.25;Yf=.23;
Lvarstr=0.15;Lvalue=0.08;Lslider=0.13;dx=0.005;
dy=0.05;
x0=0.12;y0=y00+Yf-dy;
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Position',[x00 y00 0.37 Yf], ...
	'Style','frame', ...
	'Tag','FrmParaFile');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ForegroundColor',[0 0 1], ...
	'Position',[x00+0.07 y00+Yf-0.015 0.2 Ly], ...
	'String','Parameter File', ...
	'Style','text');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(15)', ...
	'FontWeight','bold', ...
	'Position',[x0+0.29-Ly y00+Yf-0.015 Ly Ly], ...
	'String','?');

Lparafile=0.20;
hdl.krig.load_para = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Callback','radio_action(3,1)', ...
	'FontWeight','bold', ...
	'Position',[x00+0.01 y00+Yf-1.5*dy Lslider+0.02 Ly], ...
	'String','Load File', ...
	'Style','radio', ...
	'Tag','LoadParaFile');
hdl.krig.save_para = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Callback','radio_action(3,2)', ...
	'FontWeight','bold', ...
	'Position',[x00+Lslider+0.03 y00+Yf-1.5*dy Lslider+0.05 Ly], ...
	'String','Save  File', ...
	'Style','radio', ...
	'Tag','SaveParaFile');
hdl.krig.vario_para = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Callback','radio_action(3,3)', ...
	'FontWeight','bold', ...
	'Position',[x00+0.01 y00+Yf-2.6*dy Lparafile Ly], ...
	'String','variogram parameters only', ...
	'Style','radio', ...
	'Enable','off', ...
	'Tag','VarioParaFile');
hdl.krig.krig_para = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Callback','radio_action(3,4)', ...
	'FontWeight','bold', ...
	'Position',[x00+0.01 y00+Yf-3.4*dy Lparafile Ly], ...
	'String','kriging parameters only', ...
	'Style','radio', ...
	'Enable','off', ...
	'Tag','KrigParaFile');
hdl.krig.both_para = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Callback','radio_action(3,5)', ...
	'FontWeight','bold', ...
	'Position',[x00+0.01 y00+Yf-4.2*dy Lparafile Ly], ...
	'String','both parameters ', ...
	'Style','radio', ...
	'Enable','off', ...
	'Tag','BothParaFile');
hdl.krig.para_file_browser = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','file_browser(3,1)', ...
	'Position',[x00+0.03+dx+Lparafile y00+Yf-3.4*dy Lvalue Ly], ...
	'String','Browse', ...
   'Enable','off', ...
	'Tag','ParaFileBrowser');

%% Load data file frame
x00=0.11;y00=0.06;Yf=.12;
Lvarstr=0.15;Lvalue=0.08;Lslider=0.15;dx=0.005;dy=0.045;
x0=0.12;y0=y00+Yf-1.3*dy;
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Position',[x00 y00 0.37 Yf], ...
	'Style','frame', ...
	'Tag','FrmdataFile');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ForegroundColor',[0 0 1], ...
	'Position',[x00+0.07 y00+Yf-0.015 0.2 0.04], ...
	'String','Data File', ...
	'Style','text');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(16)', ...
	'FontWeight','bold', ...
	'Position',[x0+0.29-Ly y00+Yf-0.015 Ly Ly], ...
	'String','?');

hdl.krig.load_data_file = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Callback','radio_action(3,6)', ...
	'FontWeight','bold', ...
	'Position',[x00+0.04 y0 Lvarstr Ly], ...
	'String','Load ', ...
	'Style','radio', ...
	'Tag','LoadDataFile');
hdl.krig.data_file_browser = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','file_browser(3,2)', ...
	'Position',[x00+0.15 y0 Lvalue Ly], ...
	'String','Browse', ...
   'Enable','off', ...
	'Tag','DataFileBrowser');
hdl.krig.data_file = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'HorizontalAlignment','left', ...
	'Position',[x00+0.04 y0-dy 0.25 0.8*Ly], ...
	'String',' ', ...
	'Style','edit', ...
   'visible','off', ...
	'Tag','DataFileName');

%% batch processing
%%  frame
x00=0.51;y00=0.18;Yf=.18;
Lvarstr=0.22;Lvalue=0.08;Lslider=0.15;dx=0.005;dy=0.045;
x0=0.52;y0=y00+Yf-1.5*dy;
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Position',[x00 y00 0.40 Yf], ...
	'Style','frame', ...
	'Tag','FrmBatch');
hdl.krig.batch_file_proc  = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Callback','radio_action(3,7)', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ForegroundColor',[0 0 1], ...
	'Position',[x00+0.07 y00+Yf-0.015 0.30 0.04], ...
	'String','Batch Processing', ...
	'Style','radio');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(17)', ...
	'FontWeight','bold', ...
	'Position',[x0+0.37-Ly y00+Yf-0.015 Ly Ly], ...
	'String','?');

hdl.krig.batch_data_file = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','right', ...
	'Position',[x00+0.02+Ly y0 Lvarstr Ly], ...
	'String','Load filename-list file', ...
   'enable','off', ...
	'Style','text');
hdl.krig.batch_data_file_help = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(18)', ...
	'FontWeight','bold', ...
   'Enable','off', ...
	'Position',[x00+0.02 y0 Ly Ly], ...
	'String','?');
hdl.krig.batch_data_file_browser = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','file_browser(3,6)', ...
	'Position',[x00+0.3 y0 Lvalue Ly], ...
	'String','Browse', ...
   'Enable','off', ...
	'Tag','LoadBatFileBrowser');
hdl.krig.batch_log_file = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'Position',[x00+0.02+Ly y0-dy Lvarstr Ly], ...
	'HorizontalAlignment','right', ...
   'enable','off', ...
	'String','Save batch log file', ...
	'Style','text');
hdl.krig.batch_log_file_help = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','krig_help(19)', ...
	'FontWeight','bold', ...
   'Enable','off', ...
	'Position',[x00+0.02 y0-dy Ly Ly], ...
	'String','?');
hdl.krig.batch_log_file_browser = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','file_browser(3,7)', ...
	'Position',[x00+0.3 y0-dy Lvalue Ly], ...
	'String','Browse', ...
   'Enable','off', ...
	'Tag','DataFileBrowser');
hdl.krig.batch_krig = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','batch_krig', ...
	'FontWeight','bold', ...
	'Position',[x00+0.3-Lvalue y0-2*dy 2*Lvalue Ly], ...
	'String','Batch Krig', ...
   'Enable','off', ...
	'Tag','BatchKrig');

%% push buttons
pbtn_w=hdl.object.pushbtn_w;
pbtn_l=hdl.object.pushbtn_l;
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','kriging', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'Position',[0.6 0.05+pbtn_w+0.01  pbtn_l pbtn_w], ...
	'String','Krig', ...
	'Tag','Navigator');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','setkrigpara(1)', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'Position',[0.60 0.05 pbtn_l pbtn_w], ...
	'String','Refresh', ...
	'Tag','Refresh');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','figure(hdl.navigator.h0)', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'Position',[0.80 0.05+pbtn_w+0.01  pbtn_l pbtn_w], ...
	'String','Navigator', ...
	'Tag','Navigator');
h1 = uicontrol('Parent',hdl.krig.h0, ...
	'Units','normalized', ...
	'Callback','close_window(3)', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'Position',[0.80 0.05  pbtn_l pbtn_w], ...
	'String','Quit', ...
	'Tag','QuitKrig');

set(gcf,'menubar','none');
hdl.krig.h1=uimenu(hdl.krig.h0,'label','&File','separator','on');
hdl.krig.h1a=uimenu(hdl.krig.h1,'label','&Load Parameters','separator','on');
hdl.krig.h1a1=uimenu(hdl.krig.h1a,'label','Variogram Parameters','callback','file_browser(3,3,1);','separator','on');
hdl.krig.h1a2=uimenu(hdl.krig.h1a,'label','Kriging Parameters','callback','file_browser(3,3,2);','separator','on');
hdl.krig.h1a3=uimenu(hdl.krig.h1a,'label','Both Parameter Structures','callback','file_browser(3,3,3);','separator','on');
hdl.krig.h1b=uimenu(hdl.krig.h1,'label','Save &Parameters','callback','file_browser(3,4);','separator','on');
hdl.krig.h1c=uimenu(hdl.krig.h1,'label','L&Oad Data','callback','file_browser(3,5);','separator','on');
hdl.krig.h1d=uimenu(hdl.krig.h1,'label','&Quit','callback','close_window(3)','separator','on');

h2= uimenu('Parent',hdl.krig.h0,'label','&Navigator');
h2a=uimenu(h2,'label','&Open','callback','figure(hdl.navigator.h0);');
h3= uimenu('Parent',hdl.krig.h0,'label','&Load Data');
h3a= uimenu(h3,'label','&Open','callback','dataprepfig;');
h3b= uimenu(h3,'label','&Close','callback','close_window(1);');
h4=uimenu('Parent',hdl.krig.h0,'label','&Variogram');
h4a= uimenu(h4,'label','&Open','callback','fit_vario_corfig;');
h4b= uimenu(h4,'label','&Close','callback','close_window(2);');
h6= uimenu('Parent',hdl.krig.h0,'label','&Display');
h6a= uimenu(h6,'label','&Open','callback','visualizationfig;');
h6b= uimenu(h6,'label','&Close','callback','close_window(4);');
h9= uimenu('Parent',hdl.krig.h0,'label','&Quit');
h9a= uimenu(h9,'label','&Close','callback','close_window(3);');
h9b= uimenu(h9,'label','Quit &EasyKrig','callback','close all;');


getdefaultkrigpara
hdl.krig.status = 1;

if nargout > 0, fig = hdl.krig.h0; end


