function   datareduction(opt)
%% function   datareduction(opt)
%% performs data reduction or subsampling processing
%% opt = 1					get filter parameters from the window panel
%%			2					get filter parameters from variable struct
%
%%  EasyKrig Software Package  version 2.0,   October 1, 1999
%%  Copyright (c) 1999, property of Dezhang Chu and Woods Hole Oceanographic
%%  Institution.  All Rights Reserved.

global  hdl data para

if opt == 1
  para.dataprep.reduct_fac=str2num(get(hdl.dataprep.reduct_fac,'string'));
  para.dataprep.filter_supt=str2num(get(hdl.dataprep.filter_supt,'string'));
  para.dataprep.filter_type=get(hdl.dataprep.filter,'value');				% filter type: 1-simple reduction,
																								%	2-mean (box car)
																								% 	3-median
end
if ~isfield(para.dataprep,'filter_type')  % parameters have not been defined
   para.dataprep.filter_type=2;
	para.dataprep.reduct_fac=1;
   para.dataprep.filter_supt=1;
end

ninc=para.dataprep.reduct_fac;
filter_type=para.dataprep.filter_type;
supt=para.dataprep.filter_supt;

x=data.in.var1;
y=data.in.var2;
var=data.in.var;

if ninc > 1 | supt > 1
 n=length(x);
 if filter_type >= 2
   k=1;
   if rem(ninc,2) ~= 0  & ninc ~= 1 % odd ninc
      ninc=ninc+1;
   end   
   if rem(supt,2) ~= 0   % odd support
      supt=supt-1;
   end   
   for i=1:ninc:n
      if i <= supt/2
         indx=1:i+supt/2;
      elseif i > n-supt
         indx=i-supt/2:n;
      else
         indx=i-supt/2:i+supt/2;
      end
      switch filter_type 
        case 2 % box car (mean)
           xnew(k)=mean_nan(x(indx));		
           ynew(k)=mean_nan(y(indx));
           var_new(k)=mean_nan(var(indx));
        case 3	% median filter to avoid outliers
          xnew(k)=median_nan(x(indx));		
          ynew(k)=median_nan(y(indx));
          var_new(k)=median_nan(var(indx));
      end
      k=k+1;
   end
   x=xnew(:);
   y=ynew(:);
   var=var_new(:);
 else				
   x=x(1:ninc:n);
   y=y(1:ninc:n);
   var=var(1:ninc:n);
 end
end

data.in.x=x;
data.in.y=y;
data.in.v=var;