function      variogram_help(index)
%% function      variogram_help(index)
%% displays help file for variogram window
%%
%%  Kriging Software Package  version 2.0,   October 29, 1999
%%  Copyright (c) 1999, property of Dezhang Chu and Woods Hole Oceanographic
%%  Institution.  All Rights Reserved.

global hdl

switch index
  case 1
     varname='Semi-Variogram:';
     content=['This is the semi-variogram normalized by the ' ...
        'autocorrelation function at lag = 0 (variance). ' ...
        'The relation between the normalized semi-variogram and the correlogram is:'];
  case 2
     varname='Correlogram:';
     content=['This is the autocorrelation function normalized by its ' ...
        'value at lag = 0 (variance). The relation between the normalized ' ...
        'semi-variogram and the correlogram is:'];
  case 4
     varname='Nuggut:';
     content=['A quantity due to nugget effect. ', ...
        'For a semi-variogram, it is the value ' ...
        'at lag = 0, while for a coorelogram it is one minus the ' ...
        'value at lag = 0'];
  case 5
     varname='Sill:';
     content=['The asymptotic value as lag approaches infinity for ' ...
        'a semi-variogram. In most cases, this value is close to 1.'];
  case 6 
     varname='Length Scale;';
     content=['It is a normalized length scale that reflects the ascending rate for a semi-variogram ' ...
        'or the descending rate for a correlogram. The maximum normalized length scale is sqrt(1), i.e. ' ...
        'both horizontal and vertical coordinates are normalized to unity'];
  case 7
     varname='Power:';
     content=['This is a parameter used for general exponential-bessel model ' ...
        'only, and its value controls the ascending rate for a semi-variogram or ' ...
        'descending rate for a correlogram. Particularly, a power of 1 gives ' ...
        'the exponential-bessel model while a power of 2 gives the Gaussian-bessel model'];
  case 8
     varname='Scale of Hole Effect:';
     content=['It is a normalized length scale resulting from a hole structure ' ...
        'in the data, i.e., a region whose overall values are very small ' ...
        'compared with those of the adjacent regions. Such a feature will ' ...
        'generate an oscillatory pattern in either a semi-variogram ' ...
        'or a correlogram.'];
  case 9
     varname='Range:';
     content=['The maximum range for computing the semi-variogram/correlogram. ' ...
	     'It is a normalized length scale. '];
  case 10
     varname='Resolution:';
     content=['The lag resolution used in computing the semi-variogram ' ...
        'using either measured data or the theoretical variogram model. ' ...
        'It is a normalized quantity.'];
  case 11
     varname='Parameter File Browser:';
     content=['Load a parameter file using file browser.' ]
  case 12
     varname='Display Range and Value:';
     content={'Lag: displayed normalized range;',
              'Value: displayed vertical range. ' };  
  case 13
	  varname='2-D semi-variogram/coorelogram enable:';
     content=['Enable 2-D semi-variogram/coorelogram computation. ' ...
			'The 2-D semi-variogram/coorelogram map provides anisotropy information ' ...
			'which helps user(s) to chose the angle and the ratio of the anisotropic ' ...
  			'feature.'];
  case 14
     varname='Anisotropy  Angle (degree):';
     content=['This parameter specifies a rotation angle for transforming ' ...
        'the raw anisotropic data to isotropic data. Semi-variogram ' ...
		  'and kriging are performed using transformed data, but the final kriging ' ...
		  'results are still displayed in the original (unrotated) coordinates, ' ...
        'i.e., user will not see the intermediate results in their isotrophic form. ' ...
        'The angle (in degree) is measured counterclockwise with respect to the horizontal' ...
        'axes.'];
  case 15
     varname='Anisotropy Aspect Ratio:';
     content=['This parameter specifies a ratio for transforming ' ...
        'the raw anisotropic data to isotropic data. Semi-variogram ' ...
		  'and kriging are performed using transformed data, but the final kriging ' ...
		  'results are still displayed in the original (untransformed) coordinates, ' ...
		  'This parameter is defined as the ratio of the vertical length scale to the horizontal ' ...
        'length scale in the rotated coordinates (see anisotropy angle help).'];
  case 16
     varname='Anisotropy  Angle Resolution (degree):';
	  content='Angle resolution of 2-D semi-variogram/correlogram';
  case 17
	  varname='Computing:';
     content='compute 2-D semi-variogram/correlogram';
  case 18
     varname='Compute:';
     content=['Compute either the semi-variogram or correlogram using ' ...
                  'observed (measured) data.'];
  case 19
     varname='LSQ Fit:';
     content=['Perform a Least-Square Fit to find a set of parameters ' ...
                  'that characterize either the semi-variogram or the correlogram.'];
  case 20
     varname='Default:';
     content=['Restore the default parameters for computing the ' ...
                  'semi-variogram or correlogram.'];
  case 21
     varname='Apply:';
     content=['Compute the theoretical semi-variogram/correlogram using a ' ...,
                  'chosen model.'];
  case 24
     varname='Advanced:';
     content=['Advanced parameter setting for least-square-fit.'];
end
if index ~= 3 
   help_message(content,varname,[0 0 0]);
else
   modelstring(get(hdl.vario.model,'value'));
end
if index <= 2
  axes('position',[0.2 0.25 0.3 0.1]);
  ht=text(0.2,0.3,'C_h = 1 - \gamma_h','sc');
  set(ht,'fontweight','bold','fontsize',12);
  axis off
end


