function fig = fit_vario_corfig()
% function fig = fit_vario_corfig()
%%  open fitting variogram/correlogram window
%%
%%  EasyKrig Software Package  version 2.0,   October 1, 1999
%%  Copyright (c) 1999, property of Dezhang Chu and Woods Hole Oceanographic
%%  Institution.  All Rights Reserved.

global hdl data para color

grey=color.grey;
dark_grey=color.dark_grey;
blue=color.blue;

if para.status >= 1 
	if ~isempty(findobj('type','figure','Tag','FitVariogram')) 
  		figure(hdl.vario.h0);
	   if isfield(para.dataprep,'fileID')
     		set(hdl.vario.fileID,'string',para.dataprep.fileID);
  		end
  		return
	end
%% create 1-D semi-variogram/correlogram window
hdl.vario.h0 = figure('Units','normalized', ...
	'Color',[0.8 0.8 0.8], ...
	'Name','EasyKrig 2.1 -- Fit Variogram', ...
	'Position',hdl.window_position, ...
	'Tag','FitVariogram');
hdl.vario.axes1 = axes('Parent',hdl.vario.h0, ...
	'Color',[1 1 1], ...
	'Position',[0.1 0.60 0.46 0.3], ...
	'Tag','variogramAxes1');
xlabel_str='Lag (Relative to the Full Length Scale)';
ylabel_str='Semi-Variogram/Correlogram';
hx1=xlabel(xlabel_str);
hy1=ylabel(ylabel_str);
para.vario.xlabel=xlabel_str;
para.vario.ylabel=ylabel_str;
hvl1=[hx1 hy1];
set(hvl1,'fontweight','bold')

hdata=get(hdl.vario.axes1,'children');
hline=findobj(hdata,'Type','line');
if ~isempty(hline)
   set(hline,'XDATA',[],'YDATA',[]);
end

%% create 2-D semi-variogram/correlogram window
hdl.vario.axes2 = axes('Parent',hdl.vario.h0, ...
	'Color',[1 1 1], ...
	'Position',[0.1 0.1 0.35 0.34], ...
	'Tag','variogramAxes2');
	axis square
hdl.vario.colorbar2=colorbar;
set(hdl.vario.colorbar2,'visible','off');
set(get(hdl.vario.colorbar2,'children'),'visible','off');

%% 2D variogram axis-indicator
hdl.vario.axes3 = axes('Parent',hdl.vario.h0, ...
	'Color',[1 1 1], ...
	'Position',[0.1 0.38 0.04 0.04]);
hdl.vario.axis3_axis=plot([0 1],[0 0],'k',[0 0],[0 1],'k','linewidth',2);
ht1=text(1.02,0,'X');
ht2=text(-0.05,1.2,'Y');
hdl.vario.axis3_lab=[ht1 ht2];
set(hdl.vario.axis3_lab,'fontweight','bold');
axis off
   
%% FILE ID
hdl.vario.fileID = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'FontWeight','bold', ...
	'ForegroundColor',[0 0 0.501960784313725], ...
	'ListboxTop',0, ...
	'Position',[0.27 0.95 0.48 0.03], ...
	'String',para.dataprep.fileID, ...
	'Style','text', ...
	'Tag','VarioFileID');

% Parameter frame
x00=0.6;y0=0.90;
y00=0.37;
x0=0.63;Lvarstr=0.08;Lvalue=0.08;Lslider=0.1;dx=0.005;
Ly=hdl.object.edit_w;
Ly1=hdl.object.txt_w8-0.01;
dy=Ly+0.01;
Lframe=0.35;
Hframe=0.53;
hdl.vario.h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'ListboxTop',0, ...
	'Position',[x00 y00 Lframe Hframe], ...
	'Style','frame', ...
	'Tag','FrameParameter');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',blue, ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ForegroundColor',[0 0 1], ...
	'Position',[x00+5*dx  y0-0.01 Lframe-10*dx .028], ...
	'String','Model Parameters', ...
	'Style','text', ...
	'Tag','StaticText2');

%%  semi-variogram / correlogram option
Lradio1=0.13;Lradio2=0.15;
hdl.vario.variogram = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'Callback','radio_action(2,1)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0 y0-dy Lradio1 0.85*Ly], ...
	'String','variogram', ...
	'Style','radiobutton', ...
	'Tag','radioVar', ...
	'Value',1);
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(1)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+Lradio1-Ly1 y0-dy Ly1 0.85*Ly], ...
	'String','?', ...
	'Tag','VariogramHelp');
hdl.vario.correlogram = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'Callback','radio_action(2,2)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+3*dx+Lradio1 y0-dy Lradio2 0.85*Ly], ...
	'String','correlogram', ...
	'Style','radiobutton', ...
	'Tag','radioCorr');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(2)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+3*dx+2*Lradio2-Ly1 y0-dy Ly1 0.85*Ly], ...
	'String','?', ...
	'Tag','CorrelogramHelp');

%%% semi-variogram / correlogram model
model_str={'1.  sphere','2.  exponential','3.  gaussian','4.  linear','5. sinc','6. exponential-cosine (type I)', ...
    '7. exponential-cosine (type II)','8. gaussian-cosine','9. bessel (1-Jo)','10. exponential-bessel', ...
    '11. gaussian-bessel','12. gaussian-linear','13. general exponential-bessel'};
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'HorizontalAlignment','center', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+3*dx y0-2*dy Lvarstr Ly], ...
	'String',' model', ...
	'Style','text', ...
	'Tag','StaticText2');
hdl.vario.model = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','popupmenu_action(2,1)', ...   
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'Position',[x0+4*dx+Lvarstr y0-2*dy Lvarstr+Lslider+3*dx Ly], ...
	'String',model_str, ...
	'Style','popupmenu', ...
	'Tag','VariogramModel');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(3)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0 y0-2*dy Ly1 Ly], ...
	'String','?', ...
	'Tag','ModelListHelp');

%%% nugget
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'HorizontalAlignment','center', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+3*dx y0-3*dy Lvarstr Ly], ...
	'String','nugget', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(4)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0 y0-3*dy Ly1 Ly], ...
	'String','?', ...
	'Tag','NugtHelp');
hdl.vario.nugt_edit = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+4*dx+Lvarstr y0-3*dy Lvalue Ly ], ...
	'Style','edit', ...
	'Tag','NugtEdit');
hdl.vario.nugt_slider = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'Callback','slider_action(2,1)', ...
	'ListboxTop',0, ...
	'Position',[x0+5*dx+Lvarstr+Lvalue y0-3*dy Lslider Ly ], ...
	'Style','slider', ...
	'Tag','NugtSlider');

%%% sill
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'HorizontalAlignment','center', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+3*dx y0-4*dy Lvarstr Ly], ...
	'String','sill', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(5)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0 y0-4*dy Ly1 Ly], ...
	'String','?', ...
	'Tag','SillHelp');
hdl.vario.sill_edit = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+4*dx+Lvarstr y0-4*dy Lvalue Ly ], ...
	'Style','edit', ...
	'Tag','SillEdit');
hdl.vario.sill_slider = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'Callback','slider_action(2,2)', ...
	'ListboxTop',0, ...
	'Position',[x0+5*dx+Lvarstr+Lvalue y0-4*dy Lslider Ly ], ...
	'Style','slider', ...
	'Tag','SillSilder');

%%% length scale
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'HorizontalAlignment','center', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+3*dx y0-5*dy Lvarstr Ly], ...
	'String','length', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(6)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0 y0-5*dy Ly1 Ly], ...
	'String','?', ...
	'Tag','LsclHelp');
hdl.vario.lscl_edit = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+4*dx+Lvarstr y0-5*dy Lvalue Ly], ...
	'Style','edit', ...
	'Tag','LsclEdit');
hdl.vario.lscl_slider = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'Callback','slider_action(2,3)', ...
	'ListboxTop',0, ...
	'Position',[x0+5*dx+Lvarstr+Lvalue y0-5*dy Lslider Ly], ...
	'Style','slider', ...
	'Tag','LsclSlider');
%%% power
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'HorizontalAlignment','center', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+3*dx y0-6*dy Lvarstr Ly], ...
	'String','power', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(7)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0 y0-6*dy Ly1 Ly], ...
	'String','?', ...
	'Tag','PowrHelp');
hdl.vario.powr_edit = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+4*dx+Lvarstr y0-6*dy Lvalue Ly], ...
	'Style','edit', ...
	'Tag','PowrEdit');
hdl.vario.powr_slider = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'Callback','slider_action(2,4)', ...
	'ListboxTop',0, ...
	'Position',[x0+5*dx+Lvarstr+Lvalue y0-6*dy Lslider Ly], ...
	'Style','slider', ...
	'Tag','PowrSlider');

%%% length scale of hole effect
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'HorizontalAlignment','center', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+3*dx y0-7*dy Lvarstr Ly], ...
	'String','hole scl', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(8)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0 y0-7*dy Ly1 Ly], ...
	'String','?', ...
	'Tag','HoleHelp');
hdl.vario.hole_edit = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+4*dx+Lvarstr y0-7*dy Lvalue Ly], ...
	'Style','edit', ...
	'Tag','HoleEdit');
hdl.vario.hole_slider = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'Callback','slider_action(2,5)', ...
	'ListboxTop',0, ...
	'Position',[x0+5*dx+Lvarstr+Lvalue y0-7*dy Lslider Ly], ...
	'Style','slider', ...
	'Tag','HoleSlider');

%%% range
Lrange=0.055;
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','center', ...
	'ListboxTop',0, ...
	'Position',[x0+3*dx y0-8*dy Lvarstr Ly], ...
	'String','range', ...
	'Style','text', ...
	'Tag','StaticText3');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(9)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0 y0-8*dy Ly1 Ly], ...
	'String','?', ...
	'Tag','RangeHelp');
hdl.vario.range_edit = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+4*dx+Lvarstr y0-8*dy Lvalue Ly], ...
	'Style','edit', ...
	'Tag','RangeEdit');
hdl.vario.range_slider = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'Callback','slider_action(2,6)', ...
	'ListboxTop',0, ...
	'Position',[x0+5*dx+Lvarstr+Lvalue y0-8*dy Lslider Ly], ...
	'Style','slider', ...
	'Tag','RangeEdit');

%%% resolution
Lresolution=0.12;
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','center', ...
	'ListboxTop',0, ...
	'Position',[x0+3*dx y0-9*dy Lresolution Ly], ...
	'String',' resolution', ...
	'Style','text', ...
	'Tag','StaticText3');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(10)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0 y0-9*dy Ly1 Ly], ...
	'String','?', ...
	'Tag','ResolutionHelp');
hdl.vario.res = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+4*dx+Lresolution y0-9*dy Lvalue Ly], ...
	'Style','edit', ...
	'Tag','Res');

%%% parameter file
Lparafile=0.15;
hdl.vario.para_file = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Callback','radio_action(2,3)', ...
	'FontWeight','bold', ...
	'Position',[x0 y0-10*dy Lparafile Ly], ...
	'String','Parameter File', ...
	'Style','radio', ...
	'Tag','ParaFile');
hdl.vario.file_browser = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','file_browser(2,1)', ...
	'FontSize',8, ...
	'ListboxTop',0, ...
	'Position',[x0+dx+Lparafile y0-10*dy Lvarstr Ly], ...
	'String','Browse', ...
   'Enable','off', ...
	'Tag','ParaFileBrowser');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(11)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x0+dx+Lparafile+Lvarstr y0-10*dy Ly1 Ly], ...
	'String','?', ...
	'Tag','ResolutionHelp');

%% display horizontal range
%%% range
Lrange=0.08;
x03=0.1;y03=0.47;
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'ForegroundColor',[0 0 1], ...
	'FontWeight','bold', ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[x03 y03-0.01 6.0*Lvarstr 0.02+Ly], ...
	'String',' ', ...
	'Style','text', ...
	'Tag','StaticText3');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'ForegroundColor',[0 0 1], ...
	'FontWeight','bold', ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[x03+2*dx+Ly y03 1.2*Lvarstr Ly], ...
	'String','Display:', ...
	'Style','text', ...
	'Tag','StaticText3');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(12)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x03+dx y03 Ly1 Ly], ...
	'String','?', ...
	'Tag','DisplayHelp');

h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','center', ...
	'ListboxTop',0, ...
	'Position',[x03+1.2*Lvarstr+5*dx y03 Lvarstr Ly], ...
	'String','Lag', ...
	'Style','text', ...
	'Tag','StaticText3');
hdl.vario.disp_range_slider = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Callback','slider_action(2,7)', ...
	'ListboxTop',0, ...
	'Position',[x03+4*dx+2.0*Lvarstr y03 Lrange Ly], ...
	'Style','slider', ...
	'Tag','DispLagEdit');

h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','center', ...
	'ListboxTop',0, ...
	'Position',[x03+2.0*Lvarstr+15*dx+Lrange y03 Lvarstr Ly], ...
	'String','Value', ...
	'Style','text', ...
	'Tag','StaticText3');
hdl.vario.disp_value_slider = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Callback','slider_action(2,8)', ...
	'ListboxTop',0, ...
	'Position',[x03+2.0*Lvarstr+13*dx+2*Lrange y03 Lrange Ly], ...
	'Style','slider', ...
	'Tag','DispVauleEdit');

% Anisotropy
xb=0.48;yb=0.13;xf=0.3;yf=0.2;
x01=xb+2*dx;y01=yb+yf-dy-0.01;Lbutton=0.1;
Lx=0.06;Lvarstr2=0.17;
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'ListboxTop',0, ...
	'Position',[xb yb xf yf], ...
	'Style','frame', ...
	'Tag','FrameAnisotropy');
hdl.vario.enable2d = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',dark_grey, ...
	'Callback','radio_action(2,4)', ...
	'FontWeight','bold', ...
	'ForegroundColor',[0 0 1], ...
	'ListboxTop',0, ...
	'Position',[xb+4*dx yb+yf-0.0125 xf-8*dx Ly], ...
	'String','enable 2-D variogram', ...
	'Style','radio');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(13)', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[xb+xf-Ly1-4*dx yb+yf-0.0125 Ly1 Ly], ...
	'String','?', ...
	'Tag','PAS');
%% angle (orientation) of anisotropy 
hdl.vario.angle_txt = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01 y01 Lvarstr2 Ly], ...
	'String','Angle (deg)', ...
	'Style','text', ...
	'Tag','StaticText3');
hdl.vario.angle = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01+Lvarstr2+dx y01 Lx Ly], ...
	'String','0', ...
	'Style','edit', ...
	'Tag','angle');
hdl.vario.angle_help = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(14)', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01+Lvarstr2+Lx+2*dx y01 Ly1 Ly], ...
	'String','?', ...
	'Tag','PAS');

%% ratio of anisotropy
hdl.vario.ratio_txt = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01 y01-0.8*dy Lvarstr2 Ly], ...
	'String','Aspect Ratio (Y/X)', ...
	'Style','text', ...
	'Tag','StaticText3');
hdl.vario.ratio = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01+Lvarstr2+dx y01-0.8*dy Lx Ly], ...
	'String','1', ...
	'Style','edit', ...
	'Tag','ratio2');
hdl.vario.ratio_help = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(15)', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01+Lvarstr2+Lx+2*dx y01-0.8*dy Ly1 Ly], ...
	'String','?', ...
	'Tag','PAS');

%% anisotropy angle resolution
hdl.vario.ang_res_txt = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01 y01-1.6*dy Lvarstr2 Ly], ...
	'String','Angle Res. (deg)', ...
	'Style','text', ...
	'Tag','StaticText3');
hdl.vario.ang_res = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01+Lvarstr2+dx y01-1.6*dy Lx Ly], ...
	'String','1', ...
	'Style','edit', ...
	'Tag','anis_res');
hdl.vario.ang_res_help = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(16)', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01+Lvarstr2+Lx+2*dx y01-1.6*dy Ly1 Ly], ...
	'String','?', ...
	'Tag','PAS');

%% computing button
Lp=0.03;
hdl.vario.anis_cmpt = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Callback','pushbutton_action(2,1)', ...
	'FontWeight','bold', ...
	'Position',[x01+Lvarstr+dx  y01-2.4*dy 0.1  Lp], ...
	'String','computing', ...
	'Style','pushbutton', ...
	'Tag','anisotrophy_compute');
hdl.vario.anis_cmpt_help = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(17)', ...
	'BackgroundColor',grey, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01+Lvarstr+0.1+dx y01-2.4*dy Lp Lp], ...
	'String','?', ...
	'Tag','PAS');


%%% push button action
pbtn_w=hdl.object.pushbtn_w;
pbtn_l=hdl.object.pushbtn_l;

xb=0.8;yb=0.13;xf=0.15;yf=0.21;Lx=0.025;Lz=0.04;
x01=xb+Lx+2*dx;y01=yb+yf-dy;Lbutton=0.11;
h2 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'BackgroundColor',grey, ...
	'Position',[xb yb xf yf], ...
	'Style','frame', ...
	'Tag','FrameAction');
%% compute button
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','dat_vario_corr', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01 y01 Lbutton Lz], ...
	'String','Compute', ...
	'Tag','Pushbutton2');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(18)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01-Lx y01 Lx Lz], ...
	'String','?', ...
	'Tag','ComputeHelp');
%% LSQ fit button
if para.optim == 0
  optim_str='off';
else
  optim_str='on';
end
hdl.vario.lsq_fit= uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','lsqfit', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01 y01-dy Lbutton Lz], ...
	'String','LSQ Fit', ...
   'Enable',optim_str, ...
	'Tag','lsqfit');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(19)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01-Lx y01-dy Lx Lz], ...
	'String','?', ...
   'Enable',optim_str, ...
	'Tag','LSQfitHelp');
%% default button
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','getdefaultvariopara(2)', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01 y01-2*dy Lbutton Lz], ...
	'String','Default', ...
	'Tag','Default');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(20)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01-Lx y01-2*dy Lx Lz], ...
	'String','?', ...
	'Tag','DefaultHelp');
%% Apply button
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','manualfit(1)', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01 y01-3*dy Lbutton Lz], ...
	'String','Apply', ...
	'Tag','manualfig');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','variogram_help(21)', ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[x01-Lx y01-3*dy Lx Lz], ...
	'String','?', ...
	'Tag','ApplyHelp');

%% other push buttons
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','figure(hdl.navigator.h0)', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[0.65 0.05 pbtn_l pbtn_w], ...
	'String','Navigator', ...
	'Tag','Pushbutton1');
h1 = uicontrol('Parent',hdl.vario.h0, ...
	'Units','normalized', ...
	'Callback','close_window(2)', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[0.81 0.05 pbtn_l pbtn_w], ...
	'String','Quit', ...
	'Tag','Pushbutton1');
hdl.vario.status=1;
getdefaultvariopara(1);				% start a new window

if nargout > 0, fig = hdl.vario.h0; end
set(gcf,'menubar','none');
hdl.vario.h1=uimenu(hdl.vario.h0,'label','&File','separator','on');
hdl.vario.h1a=uimenu(hdl.vario.h1,'label','&Load Para','callback','file_browser(2,1);','separator','on');
hdl.vario.h1b=uimenu(hdl.vario.h1,'label','L&Oad Data','callback','dataprepfig;','separator','on');
hdl.vario.h1c=uimenu(hdl.vario.h1,'label','&Quit','callback','close_window(2)','separator','on');
h2= uimenu('Parent',hdl.vario.h0,'label','&Navigator');
h2a=uimenu(h2,'label','&Open','callback','figure(hdl.navigator.h0);');
h3= uimenu('Parent',hdl.vario.h0,'label','&Load Data');
h3a= uimenu(h3,'label','&Open','callback','dataprepfig;');
h3b= uimenu(h3,'label','&Close','callback','close_window(1);');
h5= uimenu('Parent',hdl.vario.h0,'label','&Kriging');
h5a= uimenu(h5,'label','&Open','callback','krigingfig;');
h5b= uimenu(h5,'label','&Close','callback','close_window(3);');
h6= uimenu('Parent',hdl.vario.h0,'label','&Display');
h6a= uimenu(h6,'label','&Open','callback','visualizationfig;');
h6b= uimenu(h6,'label','&Close','callback','close_window(4);');
h9= uimenu('Parent',hdl.vario.h0,'label','&Quit');
h9a= uimenu(h9,'label','&Close','callback','close_window(2);');
h9b= uimenu(h9,'label','Quit &EasyKrig','callback','close all;');

else
	message(1,'Data have not been loaded yet !!!');
end		% status >= 1