function		kriging()
%% function		kriging()
%% get kriging parameters from the Kriging GUI panel and perfrom kriging
%%
%%  Kriging Software Package  version 2.0,   October 29, 1999
%%  Copyright (c) 1999, property of Dezhang Chu and Woods Hole Oceanographic
%%  Institution.  All Rights Reserved.

global para hdl data

setkrigpara(2);	

%% variogram/correlogram model parameters
if ~isfield(data,'in')
  message(1,'Need to load data first !!');
  return
end
if ~isfield(para.vario,'model')
  message(1,'Need to load parameter file first !!');
  return
end
vmod=para.vario.model;
if para.vario.corr == 1
  vmod = -vmod;
end
model_para=[para.vario.nugt para.vario.sill para.vario.lscl para.vario.powr para.vario.hole];

%% anisotrophy parameters
anisotropy_para=[para.vario.angle para.vario.ratio];

%% kriging parameters
mod_opt=para.krig.model;
srad=para.krig.srad;
kmin=para.krig.kmin;
kmax=para.krig.kmax;
blk_opt=para.krig.scheme;
blknx=para.krig.blk_nx;
blkny=para.krig.blk_ny;
elim=para.krig.elim;
dx=para.krig.dx;
dy=para.krig.dy;
EPS=para.krig.eps;
krig_para=[blk_opt,blknx,blkny,srad,kmin,kmax,elim,dx,dy,EPS,anisotropy_para];
x=data.in.x;
y=data.in.y;
var=data.in.tv;
nx=round((para.krig.xmax-para.krig.xmin)/dx);
ny=round((para.krig.ymax-para.krig.ymin)/dy);
xg=linspace(para.krig.xmin,para.krig.xmax,nx);
yg=linspace(para.krig.ymin,para.krig.ymax,ny);
Xg=xg(ones(ny,1),:);
xc=reshape(Xg,1,nx*ny);
Yg=yg(ones(nx,1),:)';
yc=reshape(Yg,1,nx*ny);

msg1='Kriging in progress, ...';
msg2=' ';
hmsg=message(2,msg1,msg2);

t0=clock;
[Ig,ep_g]=krig(mod_opt,xc,yc,x,y,var,krig_para,vmod,model_para,hmsg);
t1=etime(clock,t0);
Ig=Ig(:);
if max(var) < 0
  indx=find(Ig > 0);
elseif min(var) > 0
  indx=find(Ig < 0 );
else
  indx=[];
end
Ig(indx)=zeros(size(indx));
krig_para(1)=1;					% station to station
msg1='Cross-Validation in progress, ...';
message(5,msg1,msg2,hmsg);

[Is,ep_s]=krig(mod_opt,x,y,xc,yc,Ig,krig_para,vmod,model_para,hmsg);
t2=etime(clock,t0);
Is=Is(:);
if max(var) < 0
  		indx=find(Is > 0);
elseif min(var) > 0
  		indx=find(Is < 0 );
end
Is(indx)=zeros(size(indx));
Is=Is(:);
para.dispkrig.Qcheck=0;
para.dispkrig.JKcheck=0;
para.dispkrig.validation_model=1;
delete(hmsg);
if para.krig.batch_file_proc == 1
 %%% 3/1/00   
   if isempty(findobj('type','figure','Tag','Popup Message'))
     para.krig.bat_proc_time=round(t2);
     msg1=[sprintf('Kriging on file # %d is done in %g (sec)',para.krig.bat_proc_cnt,para.krig.bat_proc_time)];
     hdl.krig.hmsg=message(1,msg1);
   else
     para.krig.bat_proc_time=para.krig.bat_proc_time+round(t2);
     msg1=[sprintf('Kriging on file # %d is done in %g (sec)',para.krig.bat_proc_cnt,para.krig.bat_proc_time)];
     message(3,msg1,' ',hdl.krig.hmsg);
   end
else
   msg1=['Kriging is done in ' sprintf('%g (sec)',round(t2))];
   message(1,msg1);
end

data.out.krig.nx=nx;
data.out.krig.ny=ny;
data.out.krig.xg=xg;
data.out.krig.yg=yg;
data.out.krig.Ig=Ig;
data.out.krig.eg=ep_g;
data.out.krig.Is=Is;
data.out.krig.es=ep_s;

para.status=3;

